@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -53,18 +53,20 @@ wxBitmap MyArtProvider::CreateBitmap(const wxArtID& id,
     return wxNullBitmap;
 }
 
-#include <mrpt/reactivenav.h>
+#include <mrpt/nav.h>
 #include <mrpt/gui.h>
 #include <mrpt/opengl.h>
 #include <mrpt/system/filesystem.h>
 
 using namespace mrpt;
-using namespace mrpt::slam;
+using namespace mrpt::maps;
+using namespace mrpt::obs;
 using namespace mrpt::opengl;
 using namespace mrpt::math;
 using namespace mrpt::system;
 using namespace mrpt::utils;
-using namespace mrpt::reactivenav;
+using namespace mrpt::nav;
+using namespace mrpt::poses;
 using namespace std;
 
 
@@ -422,10 +424,10 @@ holonomic_navigator_demoFrame::holonomic_navigator_demoFrame(wxWindow* parent,wx
 
 		m_simul_options.saveToConfigFile(cfg,"SIMULATOR");
 
-		mrpt::reactivenav::CHolonomicVFF holo_VFF;
+		mrpt::nav::CHolonomicVFF holo_VFF;
 		holo_VFF.options.saveToConfigFile(cfg,"VFF_CONFIG");
 
-		mrpt::reactivenav::CHolonomicND holo_ND;
+		mrpt::nav::CHolonomicND holo_ND;
 		holo_ND.options.saveToConfigFile(cfg,"ND_CONFIG");
 
 		this->edHoloParams->SetValue( _U( cfg.getContent().c_str() ) );
@@ -542,8 +544,8 @@ void holonomic_navigator_demoFrame::reinitSimulator()
 	mrpt::utils::delete_safe(m_holonomicMethod);
 	switch (rbHoloMethod->GetSelection())
 	{
-	case 0: m_holonomicMethod = new mrpt::reactivenav::CHolonomicVFF(); break;
-	case 1: m_holonomicMethod = new mrpt::reactivenav::CHolonomicND(); break;
+	case 0: m_holonomicMethod = new mrpt::nav::CHolonomicVFF(); break;
+	case 1: m_holonomicMethod = new mrpt::nav::CHolonomicND(); break;
 	default:
 		throw std::runtime_error("Invalid holonomic method selected!");
 	};
@@ -584,11 +586,11 @@ void holonomic_navigator_demoFrame::simulateOneStep(double time_step)
 	gl_scan2D->setScan( simulatedScan ); // Draw scaled scan in right-hand view
 
 	// Navigate:
-	mrpt::math::TPoint2D relTargetPose = mrpt::math::TPoint2D( CPoint2D(m_targetPoint) - CPose2D(m_robotPose) );
+	mrpt::math::TPoint2D relTargetPose = mrpt::math::TPoint2D( mrpt::poses::CPoint2D(m_targetPoint) - mrpt::poses::CPose2D(m_robotPose) );
 	relTargetPose*= 1.0/simulatedScan.maxRange;     // Normalized relative target:
 
 	double desiredDirection,desiredSpeed;
-	mrpt::reactivenav::CHolonomicLogFileRecordPtr  out_log;
+	mrpt::nav::CHolonomicLogFileRecordPtr  out_log;
 
 	//tictac.Tic();
 	this->m_holonomicMethod->navigate(
@@ -758,7 +760,7 @@ void holonomic_navigator_demoFrame::Onplot3DMouseClick(wxMouseEvent& event)
 	m_cursorPickState = cpsNone; // end of mode
 
 	// Do normal process in that class:
-	m_plot3D->OnLeftDown(event);
+	m_plot3D->OnMouseDown(event);
 }
 
 // ==== holonomic_navigator_demoFrame::TOptions ======
