@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -17,15 +17,15 @@
   ---------------------------------------------------------------*/
 
 #include <mrpt/system/os.h>
-#include <mrpt/slam/CSimpleMap.h>
-#include <mrpt/slam/CMultiMetricMap.h>
+#include <mrpt/maps/CSimpleMap.h>
+#include <mrpt/maps/CMultiMetricMap.h>
 #include <mrpt/utils/CConfigFile.h>
 #include <mrpt/utils/CFileGZInputStream.h>
 #include <mrpt/utils/CFileGZOutputStream.h>
 
 
 using namespace mrpt;
-using namespace mrpt::slam;
+using namespace mrpt::maps;
 using namespace mrpt::opengl;
 using namespace mrpt::system;
 using namespace mrpt::math;
@@ -68,7 +68,7 @@ int main(int argc, char **argv)
 
 		// Load simplemap:
 		cout << "Loading simplemap...";
-		mrpt::slam::CSimpleMap	simplemap;
+		mrpt::maps::CSimpleMap	simplemap;
 		CFileGZInputStream f( inputFile.c_str() );
 		f >> simplemap;
 		cout <<"done: " << simplemap.size() << " observations." << endl;
