@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -15,11 +15,7 @@
 
 namespace mrpt
 {
-	namespace slam
-	{
-		class CActionCollection;
-		class CSensoryFrame;
-	}
+	namespace obs { class CSensoryFrame; class CActionCollection; }
 
 	/** The namespace for Bayesian filtering algorithm: different particle filters and Kalman filter algorithms. \ingroup mrpt_base_grp
 	  */
@@ -176,8 +172,8 @@ namespace mrpt
 			 */
 			void  executeOn(
 				CParticleFilterCapable 			&obj,
-				const mrpt::slam::CActionCollection   *action,
-				const mrpt::slam::CSensoryFrame	    *observation,
+				const mrpt::obs::CActionCollection   *action,
+				const mrpt::obs::CSensoryFrame	    *observation,
 				TParticleFilterStats	        *stats = NULL);
 
 
