@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -28,26 +28,12 @@ namespace mrpt
 			// This must be added to any CSerializable derived class:
 			DEFINE_SERIALIZABLE( CMatrixB )
 		public:
-			/** Constructor
-			  */
-			CMatrixB(size_t row = 1, size_t col = 1) : CMatrixBool(row,col)
-			{
-			}
-
-			/** Copy constructor
-			  */
-			CMatrixB( const CMatrixBool &m ) : CMatrixBool(m)
-			{
-			}
-
-			/** Assignment operator for float matrixes
-			*/
-			CMatrixB & operator = (const CMatrixBool& m)
-			{
-				CMatrixBool::operator =(m);
-				return *this;
-			}
-
+			/** Constructor */
+			CMatrixB(size_t row = 1, size_t col = 1) : CMatrixBool(row,col) { }
+			/** Copy constructor */
+			CMatrixB( const CMatrixBool &m ) : CMatrixBool(m)  { }
+			/** Assignment operator for float matrixes */
+			CMatrixB & operator = (const CMatrixBool& m) { CMatrixBool::operator =(m); return *this; }
 		}; // end of class definition
 		DEFINE_SERIALIZABLE_POST_CUSTOM_BASE( CMatrixB, mrpt::utils::CSerializable )
 
