@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -87,7 +87,7 @@ namespace math	{
 		/**
 		  * Reference access operator. Checks for bounds.
 		  */
-		inline T& operator()(size_t r,size_t c)	{
+		inline T& operator()(size_t r,size_t c)	{ //-V659
 #if defined(_DEBUG) || (MRPT_ALWAYS_CHECKS_DEBUG_MATRICES)
 			if (r>=mRows||c>=mColumns) throw std::logic_error("Out of range");
 #endif
@@ -350,7 +350,7 @@ namespace math	{
 			if (it==CSparseMatrixTemplate<T>::objectList.end()) return T();
 			else return it->second;
 		}
-		inline T& operator()(size_t r,size_t c)	{
+		inline T& operator()(size_t r,size_t c)	{ //-V659
 			if (c<r) std::swap(r,c); // Symmetrical matrix
 			if (r>=CSparseMatrixTemplate<T>::mRows||c>=CSparseMatrixTemplate<T>::mColumns) throw std::logic_error("Out of range");
 			return CSparseMatrixTemplate<T>::objectList[std::make_pair(r,c)];
