@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -315,7 +315,7 @@ void Eigen::MatrixBase<Derived>::loadFromTextFile(std::istream &f)
 	std::string		str;
 	std::vector<double>	fil(512);
 	size_t	nRows = 0;
-	while ( !f.eof() )
+	while ( !f.eof() && !f.fail() )
 	{
 		std::getline(f,str);
 		if (str.size() && str[0]!='#' && str[0]!='%')
