@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -20,7 +20,7 @@
 
 namespace mrpt	{
 namespace math	{
-	using mrpt::utils::square;
+	using mrpt::utils::square;  //!< Allow square() to be also available under mrpt::math, which makes sense
 
 	/** \addtogroup geometry_grp
 	  * @{ */
@@ -49,7 +49,7 @@ namespace math	{
 		explicit TPoint2D(const TPose3D &p);
 		/**
 		  * Constructor from CPoseOrPoint, perhaps losing 3D information
-		  * \sa CPoseOrPoint,CPoint3D,CPose2D,CPose3D
+		  * \sa CPoseOrPoint mrpt::poses::CPoint3D,CPose2D,CPose3D
 		  */
 		template <class DERIVEDCLASS>
 		explicit TPoint2D(const mrpt::poses::CPoseOrPoint<DERIVEDCLASS> &p) :x(p.x()),y(p.y())	{}
@@ -57,7 +57,7 @@ namespace math	{
 		/** Implicit transformation constructor from TPixelCoordf */
 		inline TPoint2D(const mrpt::utils::TPixelCoordf &p) :x(p.x),y(p.y)	{}
 
-		/** Implicit constructor from CPoint2D  */
+		/** Implicit constructor from mrpt::poses::CPoint2D  */
 		TPoint2D(const mrpt::poses::CPoint2D &p);
 		/**
 		  * Constructor from coordinates.
@@ -481,49 +481,49 @@ namespace math	{
 	  * Exact comparison between 2D points.
 	  */
 	inline bool operator==(const TPoint2D &p1,const TPoint2D &p2)	{
-		return (p1.x==p2.x)&&(p1.y==p2.y);
+		return (p1.x==p2.x)&&(p1.y==p2.y); //-V550
 	}
 	/**
 	  * Exact comparison between 2D points.
 	  */
 	inline bool operator!=(const TPoint2D &p1,const TPoint2D &p2)	{
-		return (p1.x!=p2.x)||(p1.y!=p2.y);
+		return (p1.x!=p2.x)||(p1.y!=p2.y); //-V550
 	}
 	/**
 	  * Exact comparison between 3D points.
 	  */
 	inline bool operator==(const TPoint3D &p1,const TPoint3D &p2)	{
-		return (p1.x==p2.x)&&(p1.y==p2.y)&&(p1.z==p2.z);
+		return (p1.x==p2.x)&&(p1.y==p2.y)&&(p1.z==p2.z); //-V550
 	}
 	/**
 	  * Exact comparison between 3D points.
 	  */
 	inline bool operator!=(const TPoint3D &p1,const TPoint3D &p2)	{
-		return (p1.x!=p2.x)||(p1.y!=p2.y)||(p1.z!=p2.z);
+		return (p1.x!=p2.x)||(p1.y!=p2.y)||(p1.z!=p2.z); //-V550
 	}
 	/**
 	  * Exact comparison between 2D poses, taking possible cycles into account.
 	  */
 	inline bool operator==(const TPose2D &p1,const TPose2D &p2)	{
-		return (p1.x==p2.x)&&(p1.y==p2.y)&&(mrpt::math::wrapTo2Pi(p1.phi)==mrpt::math::wrapTo2Pi(p2.phi));
+		return (p1.x==p2.x)&&(p1.y==p2.y)&&(mrpt::math::wrapTo2Pi(p1.phi)==mrpt::math::wrapTo2Pi(p2.phi)); //-V550
 	}
 	/**
 	  * Exact comparison between 2D poses, taking possible cycles into account.
 	  */
 	inline bool operator!=(const TPose2D &p1,const TPose2D &p2)	{
-		return (p1.x!=p2.x)||(p1.y!=p2.y)||(mrpt::math::wrapTo2Pi(p1.phi)!=mrpt::math::wrapTo2Pi(p2.phi));
+		return (p1.x!=p2.x)||(p1.y!=p2.y)||(mrpt::math::wrapTo2Pi(p1.phi)!=mrpt::math::wrapTo2Pi(p2.phi)); //-V550
 	}
 	/**
 	  * Exact comparison between 3D poses, taking possible cycles into account.
 	  */
 	inline bool operator==(const TPose3D &p1,const TPose3D &p2)	{
-		return (p1.x==p2.x)&&(p1.y==p2.y)&&(p1.z==p2.z)&&(mrpt::math::wrapTo2Pi(p1.yaw)==mrpt::math::wrapTo2Pi(p2.yaw))&&(mrpt::math::wrapTo2Pi(p1.pitch)==mrpt::math::wrapTo2Pi(p2.pitch))&&(mrpt::math::wrapTo2Pi(p1.roll)==mrpt::math::wrapTo2Pi(p2.roll));
+		return (p1.x==p2.x)&&(p1.y==p2.y)&&(p1.z==p2.z)&&(mrpt::math::wrapTo2Pi(p1.yaw)==mrpt::math::wrapTo2Pi(p2.yaw))&&(mrpt::math::wrapTo2Pi(p1.pitch)==mrpt::math::wrapTo2Pi(p2.pitch))&&(mrpt::math::wrapTo2Pi(p1.roll)==mrpt::math::wrapTo2Pi(p2.roll)); //-V550
 	}
 	/**
 	  * Exact comparison between 3D poses, taking possible cycles into account.
 	  */
 	inline bool operator!=(const TPose3D &p1,const TPose3D &p2)	{
-		return (p1.x!=p2.x)||(p1.y!=p2.y)||(p1.z!=p2.z)||(mrpt::math::wrapTo2Pi(p1.yaw)!=mrpt::math::wrapTo2Pi(p2.yaw))||(mrpt::math::wrapTo2Pi(p1.pitch)!=mrpt::math::wrapTo2Pi(p2.pitch))||(mrpt::math::wrapTo2Pi(p1.roll)!=mrpt::math::wrapTo2Pi(p2.roll));
+		return (p1.x!=p2.x)||(p1.y!=p2.y)||(p1.z!=p2.z)||(mrpt::math::wrapTo2Pi(p1.yaw)!=mrpt::math::wrapTo2Pi(p2.yaw))||(mrpt::math::wrapTo2Pi(p1.pitch)!=mrpt::math::wrapTo2Pi(p2.pitch))||(mrpt::math::wrapTo2Pi(p1.roll)!=mrpt::math::wrapTo2Pi(p2.roll)); //-V550
 	}
 	//Forward declarations
 	struct BASE_IMPEXP TSegment3D;
