@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -83,7 +83,7 @@ namespace poses
 		 /** Get the phi angle of the 2D pose (in radians) */
 		 inline const double &phi() const { return m_phi; }
 		 //! \overload
-		 inline       double &phi()       { m_cossin_uptodate=false; return m_phi; }
+		 inline       double &phi()       { m_cossin_uptodate=false; return m_phi; } //-V659
 
 		 /** Get a (cached) value of cos(phi), recomputing it only once when phi changes. */
 		 inline double phi_cos() const { update_cached_cos_sin(); return m_cosphi; }
@@ -96,7 +96,7 @@ namespace poses
 		 inline void phi_incr(const double Aphi) { m_phi+=Aphi; m_cossin_uptodate=false; }  //!< Increment the PHI angle (without checking the 2 PI range, call normalizePhi is needed)
 
 		/** Returns a 1x3 vector with [x y phi] */
-		void getAsVector(CVectorDouble &v) const;
+		void getAsVector(mrpt::math::CVectorDouble &v) const;
 		/// \overload
 		void getAsVector(mrpt::math::CArrayDouble<3> &v) const;
 
