@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -257,7 +257,7 @@ namespace mrpt
 				const double				mean_x,
 				const double				mean_y,
 				double						confIntervalStds = 2,
-				const mrpt::utils::TColor 	color = mrpt::utils::TColor(255,255,255),
+				const mrpt::utils::TColor 	&color = mrpt::utils::TColor(255,255,255),
 				unsigned int				width = 1,
 				int							nEllipsePoints = 20
 				)
@@ -297,7 +297,7 @@ namespace mrpt
 			}
 
 			/** Draws a set of marks onto the image, given a generic container of entities having just "x" and "y" fields.
-			 *  The class of FEATURELIST can be, for example, std::vector<TPoint2D>, std::vector<TPixelCoordsf> or mrpt::vision::CFeatureList
+			 *  The class of FEATURELIST can be, for example, std::vector<mrpt::math::TPoint2D>, std::vector<TPixelCoordsf> or mrpt::vision::CFeatureList
 			 * \sa drawFeatures
 			 */
 			template <class FEATURELIST>
