@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -176,7 +176,7 @@ namespace utils
 			T							mean_x,
 			T							mean_y,
 			float						confIntervalStds = 2,
-			const mrpt::utils::TColor 	color = mrpt::utils::TColor(255,255,255),
+			const mrpt::utils::TColor 	&color = mrpt::utils::TColor(255,255,255),
 			unsigned int				width = 1,
 			int							nEllipsePoints = 20
 			)
