@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -26,7 +26,7 @@ namespace mrpt
 		  *  \code
 		  *     cout << TTypeName<double>::get() << endl;                          // "double"
 		  *   	cout << TTypeName<CPose2D>::get() << endl;                         // "CPose2D"
-		  *   	cout << TTypeName<mrpt::slam::COccupancyGridMap2D>::get() << endl; // "COccupancyGridMap2D"
+		  *   	cout << TTypeName<mrpt::maps::COccupancyGridMap2D>::get() << endl; // "COccupancyGridMap2D"
 		  *  \endcode
 		  *
 		  *  Users can extend this for custom structs/classes with the macro DECLARE_CUSTOM_TTYPENAME:
@@ -69,6 +69,10 @@ namespace mrpt
 			template<> struct TTypeName <_TYPE##Ptr> { \
 			static std::string get() { return TTypeName<_TYPE>::get(); }	};
 
+		#define MRPT_DECLARE_TTYPENAME_PTR_NAMESPACE(_TYPE,__NS) \
+			template<> struct TTypeName <__NS :: _TYPE##Ptr> { \
+			static std::string get() { return TTypeName<__NS :: _TYPE>::get(); }	};
+
 		MRPT_DECLARE_TTYPENAME(bool)
 		MRPT_DECLARE_TTYPENAME(double)
 		MRPT_DECLARE_TTYPENAME(float)
