@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -270,8 +270,8 @@ void CParticleFilterCapable::computeResampling(
 					prediction_and_update
  ---------------------------------------------------------------*/
 void  CParticleFilterCapable::prediction_and_update(
-	const mrpt::slam::CActionCollection	* action,
-	const mrpt::slam::CSensoryFrame		* observation,
+	const mrpt::obs::CActionCollection	* action,
+	const mrpt::obs::CSensoryFrame		* observation,
 	const bayes::CParticleFilter::TParticleFilterOptions &PF_options  )
 {
 	switch ( PF_options.PF_algorithm )
@@ -301,8 +301,8 @@ void  CParticleFilterCapable::prediction_and_update(
 					prediction_and_update_...
  ---------------------------------------------------------------*/
 void  CParticleFilterCapable::prediction_and_update_pfStandardProposal(
-	const mrpt::slam::CActionCollection	* action,
-	const mrpt::slam::CSensoryFrame		* observation,
+	const mrpt::obs::CActionCollection	* action,
+	const mrpt::obs::CSensoryFrame		* observation,
 	const bayes::CParticleFilter::TParticleFilterOptions &PF_options   )
 {
 	MRPT_UNUSED_PARAM(action); MRPT_UNUSED_PARAM(observation); MRPT_UNUSED_PARAM(PF_options);
@@ -312,8 +312,8 @@ void  CParticleFilterCapable::prediction_and_update_pfStandardProposal(
 					prediction_and_update_...
  ---------------------------------------------------------------*/
 void  CParticleFilterCapable::prediction_and_update_pfAuxiliaryPFStandard(
-	const mrpt::slam::CActionCollection	* action,
-	const mrpt::slam::CSensoryFrame		* observation,
+	const mrpt::obs::CActionCollection	* action,
+	const mrpt::obs::CSensoryFrame		* observation,
 	const bayes::CParticleFilter::TParticleFilterOptions &PF_options   )
 {
 	MRPT_UNUSED_PARAM(action); MRPT_UNUSED_PARAM(observation); MRPT_UNUSED_PARAM(PF_options);
@@ -323,8 +323,8 @@ void  CParticleFilterCapable::prediction_and_update_pfAuxiliaryPFStandard(
 					prediction_and_update_...
  ---------------------------------------------------------------*/
 void  CParticleFilterCapable::prediction_and_update_pfOptimalProposal(
-	const mrpt::slam::CActionCollection	* action,
-	const mrpt::slam::CSensoryFrame		* observation,
+	const mrpt::obs::CActionCollection	* action,
+	const mrpt::obs::CSensoryFrame		* observation,
 	const bayes::CParticleFilter::TParticleFilterOptions &PF_options   )
 {
 	MRPT_UNUSED_PARAM(action); MRPT_UNUSED_PARAM(observation); MRPT_UNUSED_PARAM(PF_options);
@@ -334,8 +334,8 @@ void  CParticleFilterCapable::prediction_and_update_pfOptimalProposal(
 					prediction_and_update_...
  ---------------------------------------------------------------*/
 void  CParticleFilterCapable::prediction_and_update_pfAuxiliaryPFOptimal(
-	const mrpt::slam::CActionCollection	* action,
-	const mrpt::slam::CSensoryFrame		* observation,
+	const mrpt::obs::CActionCollection	* action,
+	const mrpt::obs::CSensoryFrame		* observation,
 	const bayes::CParticleFilter::TParticleFilterOptions &PF_options   )
 {
 	MRPT_UNUSED_PARAM(action); MRPT_UNUSED_PARAM(observation); MRPT_UNUSED_PARAM(PF_options);
