@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -43,7 +43,7 @@ CPose3DInterpolator::CPose3DInterpolator() : m_method( CPose3DInterpolator::imLi
    Implements the writing to a CStream capability of
      CSerializable objects
   ---------------------------------------------------------------*/
-void  CPose3DInterpolator::writeToStream(CStream &out,int *version) const
+void  CPose3DInterpolator::writeToStream(mrpt::utils::CStream &out,int *version) const
 {
 	if (version)
 		*version = 0;
@@ -57,7 +57,7 @@ void  CPose3DInterpolator::writeToStream(CStream &out,int *version) const
 	Implements the reading from a CStream capability of
 		CSerializable objects
   ---------------------------------------------------------------*/
-void  CPose3DInterpolator::readFromStream(CStream &in,int version)
+void  CPose3DInterpolator::readFromStream(mrpt::utils::CStream &in,int version)
 {
 	switch(version)
 	{
@@ -511,7 +511,7 @@ void CPose3DInterpolator::filter( unsigned int component, unsigned int samples )
 	if (m_path.empty())
 		return;
 
-	std::map< mrpt::system::TTimeStamp, CPose3D > aux;
+	TPath aux;
 
 	int		ant, post;
 	size_t	nitems = size();
