@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -325,7 +325,7 @@ std::string mrpt::system::fileNameStripInvalidChars( const std::string &filename
 			*c !='+' &&
 			*c !='(' && *c !=')' &&
 			*c !='[' && *c !=']' &&
-			*c !='{' && *c !='{' )
+			*c !='{' && *c !='}' )
 				*c = '_';
 	}
 	return ret;
