@@ -26,6 +26,10 @@
 // Universal include for all versions of OpenCV
 #include <mrpt/otherlibs/do_opencv_includes.h>
 
+#if MRPT_HAS_MATLAB
+#	include <mexplus/mxarray.h>
+#endif
+
 // Prototypes of SSE2/SSE3/SSSE3 optimized functions:
 #include "CImage_SSEx.h"
 
@@ -56,7 +60,6 @@ std::string CImage::IMAGES_PATH_BASE(".");
 mrpt::utils::CTimeLogger alloc_tims;
 #endif
 
-
 /*---------------------------------------------------------------
 						Constructor
  ---------------------------------------------------------------*/
@@ -836,6 +839,20 @@ void  CImage::readFromStream(mrpt::utils::CStream &in, int version)
 #endif
 }
 
+/*---------------------------------------------------------------
+  Implements the writing to a mxArray for Matlab
+ ---------------------------------------------------------------*/
+#if MRPT_HAS_MATLAB
+// Add to implement mexplus::from template specialization
+IMPLEMENTS_MEXPLUS_FROM( mrpt::utils::CImage )
+
+mxArray* CImage::writeToMatlab() const
+{
+    cv::Mat cvImg = cv::cvarrToMat( this->getAs<IplImage>() );
+	return mexplus::from( cvImg );
+}
+#endif
+
 /*---------------------------------------------------------------
 						getSize
  ---------------------------------------------------------------*/
@@ -2049,17 +2066,17 @@ void CImage::rectifyImageInPlace( const mrpt::utils::TCamera &cameraParams  )
 	IplImage *outImg;												// Output Image
 	outImg = cvCreateImage( cvGetSize( srcImg ), srcImg->depth, srcImg->nChannels );
 
-	double aux1[3][3], aux2[1][4];
+	double aux1[3][3], aux2[1][5];
 	const CMatrixDouble33 &cameraMatrix = cameraParams.intrinsicParams;
 
 	for (int i=0;i<3;i++)
 		for (int j=0;j<3;j++)
 			aux1[i][j] = cameraMatrix(i,j);
-	for (int i=0;i<4;i++)
+	for (int i=0;i<5;i++)
 		aux2[0][i]=cameraParams.dist[i];
 
 	CvMat inMat =  cvMat( cameraMatrix.getRowCount(), cameraMatrix.getColCount(), CV_64F, aux1 );
-	CvMat distM =  cvMat( 1, 4, CV_64F, aux2 );
+	CvMat distM =  cvMat( 1, 5, CV_64F, aux2 );
 
 	// Remove distortion
 	cvUndistort2( srcImg, outImg, &inMat, &distM );
@@ -2085,17 +2102,17 @@ void CImage::rectifyImage(
 	IplImage *outImg;												// Output Image
 	outImg = cvCreateImage( cvGetSize( srcImg ), srcImg->depth, srcImg->nChannels );
 
-	double aux1[3][3], aux2[1][4];
+	double aux1[3][3], aux2[1][5];
 	const CMatrixDouble33 &cameraMatrix = cameraParams.intrinsicParams;
 
 	for (int i=0;i<3;i++)
 		for (int j=0;j<3;j++)
 			aux1[i][j] = cameraMatrix(i,j);
-	for (int i=0;i<4;i++)
+	for (int i=0;i<5;i++)
 		aux2[0][i]=cameraParams.dist[i];
 
 	CvMat inMat =  cvMat( cameraMatrix.getRowCount(), cameraMatrix.getColCount(), CV_64F, aux1 );
-	CvMat distM =  cvMat( 1, 4, CV_64F, aux2 );
+	CvMat distM =  cvMat( 1, 5, CV_64F, aux2 );
 
 	// Remove distortion
 	cvUndistort2( srcImg, outImg, &inMat, &distM );
