@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -22,19 +22,19 @@ IMPLEMENTS_SERIALIZABLE(CDetectable2D, CDetectableObject,mrpt::detectors)
 IMPLEMENTS_SERIALIZABLE(CDetectable3D, CDetectable2D,mrpt::detectors)
 
 
-void CDetectable2D::readFromStream(CStream &, int )
+void CDetectable2D::readFromStream(mrpt::utils::CStream &, int )
 {
 }
 
-void CDetectable2D::writeToStream(CStream &, int *) const
+void CDetectable2D::writeToStream(mrpt::utils::CStream &, int *) const
 {
 }
 
-void CDetectable3D::readFromStream(CStream &, int )
+void CDetectable3D::readFromStream(mrpt::utils::CStream &, int )
 {
 }
 
-void CDetectable3D::writeToStream(CStream &, int *) const
+void CDetectable3D::writeToStream(mrpt::utils::CStream &, int *) const
 {
 }
 
