@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -18,9 +18,6 @@ namespace mrpt
 {
 	namespace graphs
 	{
-	    using namespace std;
-		using namespace mrpt::utils;
-
 		/** The Dijkstra algorithm for finding the shortest path between a given source node in a (weighted) directed graph and all other nodes in the form of a tree.
 		  *  The constructor takes as input the graph (the set of directed edges) computes all the needed data, then
 		  *   successive calls to \a getShortestPathTo return the paths efficiently from the root.
@@ -187,10 +184,10 @@ namespace mrpt
 							edge_ui_weight = 1.;
 						else
 						{	// edge may be i->u or u->i:
-							edge_ui = graph.edges.find( make_pair(u,i) );
+							edge_ui = graph.edges.find( std::make_pair(u,i) );
 							if ( edge_ui==graph.edges.end() )
 							{
-								edge_ui = graph.edges.find( make_pair(i,u));
+								edge_ui = graph.edges.find( std::make_pair(i,u));
 								edge_ui_reverse = true;
 							}
 							ASSERT_(edge_ui!=graph.edges.end());
@@ -205,17 +202,17 @@ namespace mrpt
 							// If still not done above, detect the direction of the arc now:
 							if (!edge_ui_found)
 							{
-								edge_ui = graph.edges.find( make_pair(u,i) );
+								edge_ui = graph.edges.find( std::make_pair(u,i) );
 								if ( edge_ui==graph.edges.end() ) {
-									edge_ui = graph.edges.find( make_pair(i,u));
+									edge_ui = graph.edges.find( std::make_pair(i,u));
 									edge_ui_reverse = true;
 								}
 								ASSERT_(edge_ui!=graph.edges.end());
 							}
 
 							if ( !edge_ui_reverse )
-									m_prev_arc[i] = make_pair(u,i);	// *u -> *i
-							else	m_prev_arc[i] = make_pair(i,u);	// *i -> *u
+									m_prev_arc[i] = std::make_pair(u,i);	// *u -> *i
+							else	m_prev_arc[i] = std::make_pair(i,u);	// *i -> *u
 						}
 					}
 				} while ( visitedCount<nNodes );
@@ -294,10 +291,9 @@ namespace mrpt
 					const TNodeID id_to   = itArcs->second.second;
 
 					std::list<TreeEdgeInfo> &edges = out_tree.edges_to_children[id==id_from ? id_to : id_from];
-					TreeEdgeInfo newEdge;
+					TreeEdgeInfo newEdge(id);
 					newEdge.reverse = (id==id_from); // true: root towards leafs.
-					newEdge.id = id;
-					typename graph_t::edges_map_t::const_iterator itEdgeData = m_cached_graph.edges.find(make_pair(id_from,id_to));
+					typename graph_t::edges_map_t::const_iterator itEdgeData = m_cached_graph.edges.find(std::make_pair(id_from,id_to));
 					ASSERTMSG_(itEdgeData!=m_cached_graph.edges.end(),format("Edge %u->%u is in Dijkstra paths but not in original graph!",static_cast<unsigned int>(id_from),static_cast<unsigned int>(id_to) ))
 					newEdge.data = & itEdgeData->second;
 					edges.push_back( newEdge );
@@ -313,4 +309,4 @@ namespace mrpt
 
 	} // End of namespace
 } // End of namespace
-#endif
\ No newline at end of file
+#endif
