@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -23,6 +23,7 @@ using namespace mrpt::gui;
 using namespace mrpt::utils;
 using namespace mrpt::system;
 using namespace mrpt::opengl;
+using namespace mrpt::math;
 using namespace std;
 
 
@@ -195,7 +196,9 @@ void CMyGLCanvas_DisplayWindow3D::OnPostRenderSwapBuffers(double At, wxPaintDC &
 	if (m_win3D) m_win3D->internal_setRenderingFPS(At>0 ? 1.0/At : 1e9);
 
 	// If we are requested to do so, grab images to disk as they are rendered:
-	string grabFile = m_win3D->grabImageGetNextFile();
+	string grabFile; 
+	if (m_win3D) 
+		grabFile = m_win3D->grabImageGetNextFile();
 	if (m_win3D && (!grabFile.empty() || m_win3D->isCapturingImgs()) )
 	{
 		int w,h;
