@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -28,6 +28,11 @@ using namespace mrpt::slam;
 using namespace mrpt::hmtslam;
 using namespace mrpt::utils;
 using namespace mrpt::synch;
+using namespace mrpt::opengl;
+using namespace mrpt::obs;
+using namespace mrpt::maps;
+using namespace mrpt::poses;
+using namespace mrpt::math;
 using namespace std;
 
 IMPLEMENTS_SERIALIZABLE(CLocalMetricHypothesis, CSerializable,mrpt::hmtslam)
@@ -361,8 +366,8 @@ void CLocalMetricHypothesis::getAs3DScene( opengl::CSetOfObjectsPtr &objs ) cons
 
 /** The PF algorithm implementation.  */
 void  CLocalMetricHypothesis::prediction_and_update_pfAuxiliaryPFOptimal(
-	const mrpt::slam::CActionCollection	* action,
-	const mrpt::slam::CSensoryFrame		* observation,
+	const mrpt::obs::CActionCollection	* action,
+	const mrpt::obs::CSensoryFrame		* observation,
 	const bayes::CParticleFilter::TParticleFilterOptions &PF_options )
 {
 	ASSERT_(m_parent.get());
@@ -371,8 +376,8 @@ void  CLocalMetricHypothesis::prediction_and_update_pfAuxiliaryPFOptimal(
 }
 
 void  CLocalMetricHypothesis::prediction_and_update_pfOptimalProposal(
-	const mrpt::slam::CActionCollection	* action,
-	const mrpt::slam::CSensoryFrame		* observation,
+	const mrpt::obs::CActionCollection	* action,
+	const mrpt::obs::CSensoryFrame		* observation,
 	const bayes::CParticleFilter::TParticleFilterOptions &PF_options )
 {
 	ASSERT_(m_parent.get());
@@ -386,7 +391,7 @@ void  CLocalMetricHypothesis::prediction_and_update_pfOptimalProposal(
    Returns the mean of each robot pose in this LMH, as
      computed from the set of particles.
   ---------------------------------------------------------------*/
-void CLocalMetricHypothesis::getMeans( std::map< TPoseID, CPose3D > &outList ) const
+void CLocalMetricHypothesis::getMeans( TMapPoseID2Pose3D &outList ) const
 {
 	MRPT_START
 
@@ -417,7 +422,7 @@ void CLocalMetricHypothesis::getPathParticles( std::map< TPoseID, CPose3DPDFPart
 	if (m_particles.empty()) return;
 
 	// For each poseID:
-	for ( std::map<TPoseID,CPose3D>::iterator itPoseID= m_particles.begin()->d->robotPoses.begin(); itPoseID!=m_particles.begin()->d->robotPoses.end();++itPoseID )
+	for ( TMapPoseID2Pose3D::iterator itPoseID= m_particles.begin()->d->robotPoses.begin(); itPoseID!=m_particles.begin()->d->robotPoses.end();++itPoseID )
 	{
 		CPose3DPDFParticles								auxPDF( m_particles.size() );
 		CParticleList::const_iterator  					it;
@@ -451,7 +456,7 @@ void CLocalMetricHypothesis::getPoseParticles( const TPoseID &poseID, CPose3DPDF
 	for ( it = m_particles.begin(), itP = outPDF.m_particles.begin(); it!=m_particles.end(); it++, itP++ )
 	{
 		itP->log_w = it->log_w;
-		map<TPoseID,CPose3D>::const_iterator	itPose = it->d->robotPoses.find(poseID);
+		TMapPoseID2Pose3D::const_iterator	itPose = it->d->robotPoses.find(poseID);
 		ASSERT_( itPose!=it->d->robotPoses.end() );
 		*itP->d = itPose->second;
 	}
@@ -474,7 +479,6 @@ void CLocalMetricHypothesis::clearRobotPoses()
 		it->d = new CLSLAMParticleData( &m_parent->m_options.defaultMapsInitializers );
 
 		// Fill in:
-		it->d->metricMaps.options =  m_parent->m_options.defaultMapsOptions;
 		it->d->robotPoses.clear();
 	}
 }
@@ -486,7 +490,7 @@ const CPose3D * CLocalMetricHypothesis::getCurrentPose(const size_t &particleIdx
 {
 	if (particleIdx>=m_particles.size()) THROW_EXCEPTION("Particle index out of bounds!");
 
-	std::map<TPoseID,CPose3D>::const_iterator it = m_particles[particleIdx].d->robotPoses.find( m_currentRobotPose );
+	TMapPoseID2Pose3D::const_iterator it = m_particles[particleIdx].d->robotPoses.find( m_currentRobotPose );
 	ASSERT_( it!=m_particles[particleIdx].d->robotPoses.end() );
 	return & it->second;
 }
@@ -498,7 +502,7 @@ CPose3D * CLocalMetricHypothesis::getCurrentPose(const size_t &particleIdx)
 {
 	if (particleIdx>=m_particles.size()) THROW_EXCEPTION("Particle index out of bounds!");
 
-	std::map<TPoseID,CPose3D>::iterator it = m_particles[particleIdx].d->robotPoses.find( m_currentRobotPose );
+	TMapPoseID2Pose3D::iterator it = m_particles[particleIdx].d->robotPoses.find( m_currentRobotPose );
 	ASSERT_( it!=m_particles[particleIdx].d->robotPoses.end() );
 	return & it->second;
 }
@@ -522,8 +526,8 @@ void CLocalMetricHypothesis::getRelativePose(
 	{
 		itP->log_w = it->log_w;
 
-		std::map<TPoseID,CPose3D>::const_iterator  srcPose =  it->d->robotPoses.find( reference );
-		std::map<TPoseID,CPose3D>::const_iterator  trgPose =  it->d->robotPoses.find( pose );
+		TMapPoseID2Pose3D::const_iterator  srcPose =  it->d->robotPoses.find( reference );
+		TMapPoseID2Pose3D::const_iterator  trgPose =  it->d->robotPoses.find( pose );
 
 		ASSERT_( srcPose != it->d->robotPoses.end() )
 		ASSERT_( trgPose != it->d->robotPoses.end() )
@@ -546,7 +550,7 @@ void CLocalMetricHypothesis::changeCoordinateOrigin( const TPoseID &newOrigin )
 
 	for ( it = m_particles.begin(), itOrgPDF=originPDF.m_particles.begin(); it!=m_particles.end(); it++, itOrgPDF++ )
 	{
-		std::map<TPoseID,CPose3D>::iterator  refPoseIt =  it->d->robotPoses.find( newOrigin );
+		TMapPoseID2Pose3D::iterator  refPoseIt =  it->d->robotPoses.find( newOrigin );
 		ASSERT_( refPoseIt != it->d->robotPoses.end() )
 		const CPose3D  &refPose = refPoseIt->second;
 
@@ -554,9 +558,9 @@ void CLocalMetricHypothesis::changeCoordinateOrigin( const TPoseID &newOrigin )
 		*itOrgPDF->d = refPose;
 		itOrgPDF->log_w = it->log_w;
 
-		std::map<TPoseID,CPose3D>::iterator   End = it->d->robotPoses.end();
+		TMapPoseID2Pose3D::iterator   End = it->d->robotPoses.end();
 		// Change all other poses first:
-		for (std::map<TPoseID,CPose3D>::iterator  itP=it->d->robotPoses.begin();itP!=End;++itP)
+		for (TMapPoseID2Pose3D::iterator  itP=it->d->robotPoses.begin();itP!=End;++itP)
 			if (itP!=refPoseIt)
 				itP->second = itP->second - refPose;
 
@@ -596,8 +600,8 @@ void CLocalMetricHypothesis::rebuildMetricMaps()
 		it->d->metricMaps.clear();
 
 		// Follow all robot poses:
-		std::map<TPoseID,CPose3D>::iterator   End = it->d->robotPoses.end();
-		for (std::map<TPoseID,CPose3D>::iterator  itP=it->d->robotPoses.begin();itP!=End;++itP)
+		TMapPoseID2Pose3D::iterator   End = it->d->robotPoses.end();
+		for (TMapPoseID2Pose3D::iterator  itP=it->d->robotPoses.begin();itP!=End;++itP)
 		{
 			if ( itP->first != m_currentRobotPose )  // Current robot pose has no SF stored.
 			{
@@ -860,10 +864,10 @@ void  CLocalMetricHypothesis::dumpAsText(utils::CStringList &st) const
 		s+=format("%i ",(int)*it);
 	st << s;
 
-	map<TPoseID,CPose3D> lst;
+	TMapPoseID2Pose3D lst;
 	getMeans( lst );
 
-	for (map<TPoseID,CPose3D>::const_iterator it=lst.begin();it!=lst.end();++it)
+	for (TMapPoseID2Pose3D::const_iterator it=lst.begin();it!=lst.end();++it)
 	{
 		map<TPoseID,CHMHMapNode::TNodeID>::const_iterator	area = m_nodeIDmemberships.find(it->first);
 
@@ -879,7 +883,7 @@ void  CLocalMetricHypothesis::dumpAsText(utils::CStringList &st) const
 /*---------------------------------------------------------------
 					readFromStream
   ---------------------------------------------------------------*/
-void  CLocalMetricHypothesis::readFromStream(CStream &in,int version)
+void  CLocalMetricHypothesis::readFromStream(mrpt::utils::CStream &in,int version)
 {
 	switch(version)
 	{
@@ -909,7 +913,7 @@ void  CLocalMetricHypothesis::readFromStream(CStream &in,int version)
 	Implements the writing to a CStream capability of
 	  CSerializable objects
   ---------------------------------------------------------------*/
-void  CLocalMetricHypothesis::writeToStream(CStream &out, int *version) const
+void  CLocalMetricHypothesis::writeToStream(mrpt::utils::CStream &out, int *version) const
 {
 	if (version)
 		*version = 0;
@@ -935,7 +939,7 @@ void  CLocalMetricHypothesis::writeToStream(CStream &out, int *version) const
 /*---------------------------------------------------------------
 					readFromStream
   ---------------------------------------------------------------*/
-void  CLSLAMParticleData::readFromStream(CStream &in,int version)
+void  CLSLAMParticleData::readFromStream(mrpt::utils::CStream &in,int version)
 {
 	switch(version)
 	{
@@ -953,7 +957,7 @@ void  CLSLAMParticleData::readFromStream(CStream &in,int version)
 	Implements the writing to a CStream capability of
 	  CSerializable objects
   ---------------------------------------------------------------*/
-void  CLSLAMParticleData::writeToStream(CStream &out, int *version) const
+void  CLSLAMParticleData::writeToStream(mrpt::utils::CStream &out, int *version) const
 {
 	if (version)
 		*version = 0;
