@@ -2,14 +2,14 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
 #ifndef CCANBusReader_H
 #define CCANBusReader_H
 
-#include <mrpt/slam/CObservationCANBusJ1939.h>
+#include <mrpt/obs/CObservationCANBusJ1939.h>
 #include <mrpt/utils/CDebugOutputCapable.h>
 #include <mrpt/hwdrivers/CGenericSensor.h>
 #include <mrpt/hwdrivers/CSerialPort.h>
@@ -139,7 +139,7 @@ namespace mrpt
 			  */
 			void  doProcessSimple(
 				bool							    &outThereIsObservation,
-				mrpt::slam::CObservationCANBusJ1939	&outObservation,
+				mrpt::obs::CObservationCANBusJ1939	&outObservation,
 				bool							    &hardwareError );
 
 			/** Set-up communication with the laser.
