@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -12,7 +12,7 @@
 
 #include <mrpt/utils/CConfigFileBase.h>
 #include <mrpt/utils/CUncopiable.h>
-#include <mrpt/slam/CObservation.h>
+#include <mrpt/obs/CObservation.h>
 #include <mrpt/synch/CCriticalSection.h>
 #include <mrpt/system/threads.h>
 #include <map>
@@ -134,7 +134,7 @@ namespace mrpt
 			/** This method must be called by derived classes to enqueue a new observation in the list to be returned by getObservations.
 			  *  Passed objects must be created in dynamic memory and a smart pointer passed. Example of creation:
 			  \code
-				CObservationGPSPtr  o = CObservationGPSPtr( new CObservationGPS() );
+				mrpt::obs::CObservationGPSPtr  o = CObservationGPSPtr( new CObservationGPS() );
 				o-> .... // Set data
 				appendObservation(o);
 			  \endcode
