@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -14,7 +14,7 @@
 #include <mrpt/hwdrivers/link_pragmas.h>
 #include <mrpt/synch/CCriticalSection.h>
 #include <mrpt/synch/CThreadSafeVariable.h>
-#include <mrpt/slam/CObservationImage.h>
+#include <mrpt/obs/CObservationImage.h>
 
 #include <mrpt/hwdrivers/CGenericSensor.h>
 
@@ -23,9 +23,6 @@ namespace mrpt
 {
 	namespace hwdrivers
 	{
-		using namespace std;
-		using namespace mrpt::slam;
-		
 		/** A class to interface a Rovio robot (manufactured by WowWee).
 		  *  Supports: Simple motion commands, video streaming. 
 		  * \ingroup mrpt_hwdrivers_grp
@@ -39,7 +36,7 @@ namespace mrpt
 			bool	m_videothread_initialized_error;
 			bool    m_videothread_finished;
 
-			mrpt::slam::CObservationImagePtr buffer_img;
+			mrpt::obs::CObservationImagePtr buffer_img;
 			mrpt::synch::CCriticalSection buffer_img_cs;
 
 
@@ -51,17 +48,17 @@ namespace mrpt
 
 			bool path_management(int act);
 
-			bool path_management(int act, const string &path_name);
+			bool path_management(int act, const std::string &path_name);
 
-			bool general_command(int act, string &response, string &errormsg);
+			bool general_command(int act, std::string &response, std::string &errormsg);
 
 
 		public:
 			struct TOptions
 			{
-				string IP;
-				string user;
-				string password;
+				std::string IP;
+				std::string user;
+				std::string password;
 
 				mrpt::utils::TCamera cameraParams;		// Mat. cam. preguntar paco
 
@@ -92,7 +89,7 @@ namespace mrpt
 			/** Establish conection with Rovio and log in its system: Important, fill out "options" members *BEFORE* calling this method.
 			  *  \exception std::runtime On errors
 			  */ 
-			void initialize(); //string &errormsg_out, string url_out="150.214.109.134", string user_out="admin", string password_out="investigacion");
+			void initialize(); //string &errormsg_out, std::string url_out="150.214.109.134", std::string user_out="admin", std::string password_out="investigacion");
 
 			/**	move send Rovio the command to move in the specified direcction
 			  * \param direction 'f'->forward, 'b'->backward, 'r'->right, 'l'->left
@@ -117,16 +114,16 @@ namespace mrpt
 			/*  Path commands */ 
 			bool pathRecord();
 			bool pathRecordAbort();
-			bool pathRecordSave(const string &path_name);//Repasar const
-			bool pathDelete(const string &path_name);
+			bool pathRecordSave(const std::string &path_name);//Repasar const
+			bool pathDelete(const std::string &path_name);
 			/** Get list of saved paths
 			  */ 
-			bool pathGetList(string &path_list);
+			bool pathGetList(std::string &path_list);
 			bool pathRunForward();
 			bool pathRunBackward();
 			bool pathRunStop();
 			bool pathRunPause();
-			bool pathRename(const string &old_name, const string &new_name);
+			bool pathRename(const std::string &old_name, const std::string &new_name);
 
 
 			/** goHome(bool dock) drives Rovio in front of charging station if the paremeter dock is set to false, otherwise it also docks
@@ -157,14 +154,14 @@ namespace mrpt
 			  * \return False on error
 			  * \sa retrieve_video, captureImageAsync
 			  */
-			bool getNextImageSync(CObservationImagePtr& lastImage );
+			bool getNextImageSync(mrpt::obs::CObservationImagePtr& lastImage );
 
 			/** Returns a snapshot from Rovio, if rectified is set true, the returned image is rectified with the parameters of intrinsic_matrix and distortion_matrix.
 			  * This function works asynchronously and does not need to have enabled the live video streaming.
 			  * \return False on error
 			  * \sa captureImageSync
 			  */
-			bool captureImageAsync( CImage&out_img, bool recttified);//string pict_name, 
+			bool captureImageAsync( mrpt::utils::CImage&out_img, bool recttified);//string pict_name, 
 
 			bool isVideoStreamming() const; //!< Return true if video is streaming correctly \sa retrieve_video
 
