@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -16,7 +16,7 @@
 
 using namespace std;
 using namespace mrpt::utils;
-using namespace mrpt::slam;
+using namespace mrpt::obs;
 using namespace mrpt::hwdrivers;
 
 /*-------------------------------------------------------------
@@ -54,7 +54,7 @@ void  C2DRangeFinderAbstract::bindIO( CStream	*streamIO )
 -------------------------------------------------------------*/
 void  C2DRangeFinderAbstract::getObservation(
 	bool							&outThereIsObservation,
-	mrpt::slam::CObservation2DRangeScan	&outObservation,
+	mrpt::obs::CObservation2DRangeScan	&outObservation,
 	bool							&hardwareError )
 {
 	m_csLastObservation.enter();
@@ -162,7 +162,7 @@ void C2DRangeFinderAbstract::loadCommonParams(
 /*-------------------------------------------------------------
 						filterByExclusionAreas
 -------------------------------------------------------------*/
-void C2DRangeFinderAbstract::filterByExclusionAreas( mrpt::slam::CObservation2DRangeScan &obs) const
+void C2DRangeFinderAbstract::filterByExclusionAreas( mrpt::obs::CObservation2DRangeScan &obs) const
 {
 	obs.filterByExclusionAreas( m_lstExclusionPolys );
 }
@@ -170,13 +170,13 @@ void C2DRangeFinderAbstract::filterByExclusionAreas( mrpt::slam::CObservation2DR
 /*-------------------------------------------------------------
 						filterByExclusionAngles
 -------------------------------------------------------------*/
-void C2DRangeFinderAbstract::filterByExclusionAngles( mrpt::slam::CObservation2DRangeScan &obs) const
+void C2DRangeFinderAbstract::filterByExclusionAngles( mrpt::obs::CObservation2DRangeScan &obs) const
 {
 	obs.filterByExclusionAngles( m_lstExclusionAngles );
 }
 
 
-void C2DRangeFinderAbstract::processPreview(const mrpt::slam::CObservation2DRangeScan &obs)
+void C2DRangeFinderAbstract::processPreview(const mrpt::obs::CObservation2DRangeScan &obs)
 {
 	using namespace mrpt::opengl;
 
