@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -25,7 +25,7 @@ IMPLEMENTS_GENERIC_SENSOR(CCANBusReader,mrpt::hwdrivers)
 using namespace std;
 using namespace mrpt;
 using namespace mrpt::utils;
-using namespace mrpt::slam;
+using namespace mrpt::obs;
 using namespace mrpt::hwdrivers;
 
 char hexCharToInt(char n)
@@ -80,7 +80,7 @@ CCANBusReader::~CCANBusReader()
 
 void  CCANBusReader::doProcess()
 {
-    mrpt::slam::CObservationCANBusJ1939Ptr	obs = mrpt::slam::CObservationCANBusJ1939::Create();
+    mrpt::obs::CObservationCANBusJ1939Ptr	obs = mrpt::obs::CObservationCANBusJ1939::Create();
     bool thereIsObservation;
     bool hardwareError;
 
@@ -96,7 +96,7 @@ void  CCANBusReader::doProcess()
 -------------------------------------------------------------*/
 void  CCANBusReader::doProcessSimple(
 	bool							    &outThereIsObservation,
-	mrpt::slam::CObservationCANBusJ1939	&outObservation,
+	mrpt::obs::CObservationCANBusJ1939	&outObservation,
 	bool							    &hardwareError )
 {
 	outThereIsObservation	= false;
@@ -568,7 +568,6 @@ bool CCANBusReader::waitACK(uint16_t timeout_ms)
 	CTicTac tictac;
 	tictac.Tic();
 
-    bool found = false;
 	do
 	{
 		if ( m_mySerialPort->Read(&b,1) )
@@ -581,7 +580,7 @@ bool CCANBusReader::waitACK(uint16_t timeout_ms)
 			}
 
 		}
-	} while( !found && tictac.Tac()<timeout_ms*1e-3  );
+	} while(tictac.Tac()<timeout_ms*1e-3 );
 
 	if (b==0x07)                            // [BELL]
         RET_ERROR(format("ERROR received."))
