@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -14,7 +14,7 @@
 #include <mrpt/hwdrivers/CGPSInterface.h>
 
 using namespace mrpt::hwdrivers;
-using namespace mrpt::slam;
+using namespace mrpt::obs;
 using namespace mrpt::system;
 using namespace mrpt::synch;
 using namespace std;
@@ -431,7 +431,7 @@ void  CGPSInterface::processGPSstring(const std::string &s)
 /* -----------------------------------------------------
 					parse_NMEA
 ----------------------------------------------------- */
-bool CGPSInterface::parse_NMEA(const std::string &s, mrpt::slam::CObservationGPS &out_obs, const bool verbose)
+bool CGPSInterface::parse_NMEA(const std::string &s, mrpt::obs::CObservationGPS &out_obs, const bool verbose)
 {
     if (verbose)
 		cout << "[CGPSInterface] GPS raw string: " << s << endl;
