@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -148,8 +148,16 @@ TCaptureOptions_FlyCapture2::TCaptureOptions_FlyCapture2() :
 	strobe_polarity(0),
 	strobe_delay(0.0f),
 	strobe_duration(1.0f),
+    autoexposure_auto(true),
+    autoexposure_onOff(true),
+    autoexposure_abs(true),
+    autoexposure_EV(0.0f),
 	shutter_auto(true),
+    shutter_abs(true),
 	shutter_time_ms(4.0f),
+    gain_auto(true),
+    gain_abs(true),
+    gain_dB(0.0f),
 	stereo_mode(false),
 	get_rectified(false),
 	rect_width(640),
@@ -194,9 +202,19 @@ void TCaptureOptions_FlyCapture2::loadOptionsFrom(
 	strobe_delay = cfg.read_float(sect, prefix+string("strobe_delay"), strobe_delay);
 	strobe_duration = cfg.read_float(sect, prefix+string("strobe_duration"), strobe_duration);
 
+    autoexposure_auto = cfg.read_bool(sect, prefix+string("autoexposure_auto"), autoexposure_auto);
+    autoexposure_onOff = cfg.read_bool(sect, prefix+string("autoexposure_onOFf"), autoexposure_onOff);
+    autoexposure_abs = cfg.read_bool(sect, prefix+string("autoexposure_abs"), autoexposure_abs);
+    autoexposure_EV = cfg.read_float(sect, prefix+string("autoexposure_EV"), autoexposure_EV);
+
 	shutter_auto = cfg.read_bool(sect, prefix+string("shutter_auto"), shutter_auto);
+    shutter_abs = cfg.read_bool(sect, prefix+string("shutter_abs"), shutter_abs);
 	shutter_time_ms = cfg.read_float(sect, prefix+string("shutter_time_ms"), shutter_time_ms);
 
+    gain_auto = cfg.read_bool(sect, prefix+string("gain_auto"), gain_auto);
+    gain_abs = cfg.read_bool(sect, prefix+string("gain_abs"), gain_abs);
+    gain_dB = cfg.read_float(sect, prefix+string("gain_dB"), gain_dB);
+
 	stereo_mode = cfg.read_bool(sect, prefix+string("stereo_mode"), stereo_mode);
 	get_rectified = cfg.read_bool(sect, prefix+string("get_rectified"), get_rectified);
 	rect_width = cfg.read_uint64_t(sect, prefix+string("rect_width"), rect_width);
@@ -266,7 +284,7 @@ void CImageGrabber_FlyCapture2::open( const TCaptureOptions_FlyCapture2 &options
 		BusManager busMgr;
 		unsigned int numCameras;
 		fe = busMgr.GetNumOfCameras(&numCameras);
-		CHECK_FC2_ERROR(fe)
+        CHECK_FC2_ERROR(fe)
 
 		if (m_options.camera_index>=numCameras)
 			THROW_EXCEPTION(mrpt::format("Error: camera_index to open is '%u', but only '%u' cameras were detected in the system.",m_options.camera_index,numCameras))
@@ -431,44 +449,78 @@ void CImageGrabber_FlyCapture2::open( const TCaptureOptions_FlyCapture2 &options
 	fe = FC2_CAM->SetConfiguration( &fc2conf);
 	CHECK_FC2_ERROR(fe)
 
+    /*// Set the shutter property of the camera
+    Property prop;
+    prop.type = SHUTTER;
+    error = cam.GetProperty( &prop );
+    if (error != PGRERROR_OK)
+    {
+        PrintError( error );
+        return -1;
+    }
+
+    prop.autoManualMode = false;
+    prop.absControl = true;
+
+    const float k_shutterVal = 30000.0;
+    prop.absValue = k_shutterVal;*/
+
 	// Autoexposure:
     {
 		FlyCapture2::Property p;
 		p.type = FlyCapture2::AUTO_EXPOSURE;
-		p.autoManualMode = true; // true=auto
-		p.onOff = true;
+        FlyCapture2::Error error = FC2_CAM->GetProperty( &p );
+        CHECK_FC2_ERROR(error)
+        p.autoManualMode = m_options.autoexposure_auto; // true=auto
+        p.onOff = m_options.autoexposure_onOff; // true=on
+        p.absControl = m_options.autoexposure_abs; // true=abs
+        MRPT_TODO("Add integer value case")
+        p.absValue = m_options.autoexposure_EV; // abs value in Exposure Value (EV)
 		fe = FC2_CAM->SetProperty (&p);
+        CHECK_FC2_ERROR(fe)
 	}
 
 	// Brightness:
     {
 		FlyCapture2::Property p;
 		p.type = FlyCapture2::BRIGHTNESS;
+        FlyCapture2::Error error = FC2_CAM->GetProperty( &p );
+        CHECK_FC2_ERROR(error)
 		p.autoManualMode = true; // true=auto
 		//p.absControl = true;
 		//p.absValue = Brightness;
 		fe = FC2_CAM->SetProperty (&p);
+        CHECK_FC2_ERROR(fe)
 	}
 
+    // Shutter:
     {
 		FlyCapture2::Property p;
 		p.type = FlyCapture2::SHUTTER;
+        FlyCapture2::Error error = FC2_CAM->GetProperty( &p );
+        CHECK_FC2_ERROR(error)
 		p.autoManualMode = m_options.shutter_auto; // true=auto
-	    p.absControl = true;
+        p.absControl = m_options.shutter_abs; // true=abs
+        MRPT_TODO("Add integer value case")
 		p.absValue = m_options.shutter_time_ms;
 	    //p.onOff = false;
 		fe = FC2_CAM->SetProperty (&p);
 		CHECK_FC2_ERROR(fe)
 	}
 
+    // Gain:
     {
 		FlyCapture2::Property p;
 		p.type = FlyCapture2::GAIN;
-		p.autoManualMode = true; // true=auto
-	    //p.absControl = true;
-	    //p.absValue = Gain;
+        FlyCapture2::Error error = FC2_CAM->GetProperty( &p );
+        CHECK_FC2_ERROR(error)
+        p.autoManualMode = m_options.gain_auto; // true=auto
+        p.absControl = m_options.gain_abs; // true=abs
+        MRPT_TODO("Add integer value case")
+        p.absValue = m_options.gain_dB; // abs value in dB (decibeles)
 	    //p.onOff = false;
 		fe = FC2_CAM->SetProperty (&p);
+        CHECK_FC2_ERROR(fe)
 	}
 
 	// Framecounter:
@@ -600,7 +652,7 @@ std::string CImageGrabber_FlyCapture2::getFC2version()
  -------------------------------------------------------------*/
 // Grab image from the camera. This method blocks until the next frame is captured.
 // return: false on any error.
-bool CImageGrabber_FlyCapture2::getObservation( mrpt::slam::CObservationImage &out_observation )
+bool CImageGrabber_FlyCapture2::getObservation( mrpt::obs::CObservationImage &out_observation )
 {
 #if MRPT_HAS_FLYCAPTURE2
 if (!m_camera) {
@@ -651,7 +703,7 @@ THROW_EXCEPTION("MRPT compiled without support for FlyCapture2")
  -------------------------------------------------------------*/
 // Grab image from the camera. This method blocks until the next frame is captured.
 // return: false on any error.
-bool CImageGrabber_FlyCapture2::getObservation( mrpt::slam::CObservationStereoImages &out_observation )
+bool CImageGrabber_FlyCapture2::getObservation( mrpt::obs::CObservationStereoImages &out_observation )
 {
 #if MRPT_HAS_FLYCAPTURE2 && MRPT_HAS_TRICLOPS && MRPT_HAS_OPENCV
 	if (!m_camera) {
