@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -196,7 +196,7 @@ CImageGrabber_OpenCV::~CImageGrabber_OpenCV()
 /*-------------------------------------------------------------
 					get the image
  -------------------------------------------------------------*/
-bool  CImageGrabber_OpenCV::getObservation( mrpt::slam::CObservationImage &out_observation)
+bool  CImageGrabber_OpenCV::getObservation( mrpt::obs::CObservationImage &out_observation)
 {
    MRPT_START
 
