@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -22,6 +22,8 @@ using namespace mrpt;
 using namespace mrpt::system;
 using namespace mrpt::utils;
 using namespace mrpt::hwdrivers;
+using namespace mrpt::poses;
+using namespace mrpt::obs;
 using namespace std;
 
 
