@@ -2,17 +2,17 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
 
 #include "hwdrivers-precomp.h"   // Precompiled headers
 
-//#include <mrpt/system/os.h>
 #include <mrpt/hwdrivers/CRoboticHeadInterface.h>
 
 using namespace mrpt::utils;
+using namespace mrpt::math;
 using namespace mrpt::hwdrivers;
 
 /*-------------------------------------------------------------
