@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -25,8 +25,9 @@ IMPLEMENTS_GENERIC_SENSOR(CSickLaserUSB,mrpt::hwdrivers)
 using namespace std;
 using namespace mrpt;
 using namespace mrpt::utils;
-using namespace mrpt::slam;
+using namespace mrpt::obs;
 using namespace mrpt::hwdrivers;
+using namespace mrpt::poses;
 
 
 /*-------------------------------------------------------------
@@ -48,10 +49,8 @@ CSickLaserUSB::CSickLaserUSB() :
 -------------------------------------------------------------*/
 CSickLaserUSB::~CSickLaserUSB()
 {
-	MRPT_START
 	delete m_usbConnection;
 	m_usbConnection = NULL;
-	MRPT_END
 }
 
 /*-------------------------------------------------------------
@@ -59,7 +58,7 @@ CSickLaserUSB::~CSickLaserUSB()
 -------------------------------------------------------------*/
 void  CSickLaserUSB::doProcessSimple(
 	bool							&outThereIsObservation,
-	mrpt::slam::CObservation2DRangeScan	&outObservation,
+	mrpt::obs::CObservation2DRangeScan	&outObservation,
 	bool							&hardwareError )
 {
 	outThereIsObservation	= false;
