@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -16,6 +16,7 @@
 
 using namespace mrpt::hwdrivers;
 using namespace mrpt::system;
+using namespace std;
 
 IMPLEMENTS_GENERIC_SENSOR(CSwissRanger3DCamera,mrpt::hwdrivers)
 
@@ -158,7 +159,7 @@ void CSwissRanger3DCamera::initialize()
 */
 void CSwissRanger3DCamera::doProcess()
 {
-	using namespace mrpt::slam;
+	using namespace mrpt::obs;
 
 	bool	thereIs, hwError;
 
@@ -339,7 +340,7 @@ void CSwissRanger3DCamera::internal_resendParamsToCamera() const
   * \sa doProcess
   */
 void CSwissRanger3DCamera::getNextObservation(
-	mrpt::slam::CObservation3DRangeScan &_out_obs,
+	mrpt::obs::CObservation3DRangeScan &_out_obs,
 	bool &there_is_obs,
 	bool &hardware_error )
 {
@@ -367,7 +368,7 @@ void CSwissRanger3DCamera::getNextObservation(
 	}
 
 	// Initialize the output observation:
-	CObservation3DRangeScan obs;
+	obs::CObservation3DRangeScan obs;
 	obs.sensorLabel     = m_sensorLabel;
 	obs.sensorPose		= m_sensorPoseOnRobot;
 	obs.maxRange  = m_maxRange;
@@ -521,7 +522,7 @@ void CSwissRanger3DCamera::getNextObservation(
 
 				mrpt::utils::CImage  img;
 				// Normalize the image
-				CMatrixFloat  range2D = _out_obs.rangeImage;
+				math::CMatrixFloat  range2D = _out_obs.rangeImage;
 				range2D*= 1.0/m_maxRange;
 				img.setFromMatrix(range2D);
 				m_win_range->showImage(img);
