@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -318,7 +318,7 @@ AREXPORT void ArSyncTask::log(int depth)
   
   for (i = 0; i < depth; i++)
     str += "\t";
-  str += myName.c_str();
+  str += myName;
   str += " (";
   state = getState();
   switch (state) 
