@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -144,7 +144,7 @@ struct XsMessage {
 		\param msgId		The message Id that will be assigned to the m_messageId field.
 		\param dataLength	The length of the data in the message.
 	*/
-	XsMessage(XsXbusMessageId msgId = XMID_InvalidMessage, XsSize dataLength = 0)
+	explicit XsMessage(XsXbusMessageId msgId = XMID_InvalidMessage, XsSize dataLength = 0)
 		: m_autoUpdateChecksum(1)
 		, m_checksum(0)
 	{
