@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -2046,7 +2046,7 @@ void XsDataPacket_setTriggerIndication(XsDataPacket* thisPtr, XsDataIdentifier t
 		XsMessage_resizeData(&thisPtr->m_msg, sz + 3 + DATASIZE);
 
 		XsMessage_setDataShort(&thisPtr->m_msg, triggerId, sz);
-		XsMessage_setDataByte(&thisPtr->m_msg, DATASIZE, sz + 2);
+		XsMessage_setDataByte(&thisPtr->m_msg, (uint8_t) DATASIZE, sz + 2);
 		++thisPtr->m_itemCount;
 	}
 
