@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -40,12 +40,6 @@ const char *XsDataFlags_toString(XsDataFlags f)
 			strcat(rv, " | ");
 		strcat(rv, "XSDF_Empty");
 	}
-	if (f & XSDF_DestructiveCopy)
-	{
-		if (rv[0])
-			strcat(rv, " | ");
-		strcat(rv, "XSDF_DestructiveCopy");
-	}
 	return rv;
 }
 
