@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -156,10 +156,7 @@ namespace mrpt
 	// (This is to ease serialization)
 	namespace utils
 	{
-		using namespace ::mrpt::kinematics;
-
-		MRPT_DECLARE_TTYPENAME(TKinematicLink)
-
+		MRPT_DECLARE_TTYPENAME_NAMESPACE(TKinematicLink,::mrpt::kinematics)
 	} // End of namespace
 
 } // End of namespace
