@@ -22,6 +22,9 @@
 #include <mrpt/maps/link_pragmas.h>
 #include <mrpt/utils/adapters.h>
 
+// Add for declaration of mexplus::from template specialization
+DECLARE_MEXPLUS_FROM( mrpt::maps::CPointsMap )
+
 namespace mrpt
 {
 /** \ingroup mrpt_maps_grp */
@@ -57,6 +60,8 @@ namespace maps
 	{
 		// This must be added to any CSerializable derived class:
 		DEFINE_VIRTUAL_SERIALIZABLE( CPointsMap )
+		// This must be added for declaration of MEX-related functions
+		DECLARE_MEX_CONVERSION
 
 	protected:
 		/** Helper struct used for \a internal_loadFromRangeScan2D_prepareOneRange() */
