@@ -20,10 +20,9 @@
 #include <mrpt/maps/COccupancyGridMap2D.h>
 
 #include <mrpt/maps/link_pragmas.h>
-
-#if EIGEN_VERSION_AT_LEAST(3,1,0)
-// #define EIGEN_YES_I_KNOW_SPARSE_MODULE_IS_NOT_STABLE_YET  // No need to for this macro in Eigen 3.1+
-#	include <Eigen/Sparse>
+#if EIGEN_VERSION_AT_LEAST(3,1,0) // eigen 3.1+
+	#include <Eigen/SparseCore>
+	#include <Eigen/SparseCholesky>
 #endif
 
 namespace mrpt
