@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -140,7 +140,7 @@ namespace octomap {
     void addKey(OcTreeKey& k) {
       assert(end_of_ray != ray.end());
       *end_of_ray = k;
-      end_of_ray++;
+      ++end_of_ray;
     }
 
     size_t size() const { return end_of_ray - ray.begin(); }
