@@ -2,15 +2,15 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
 
 #include "maps-precomp.h" // Precomp header
 
-#include <mrpt/slam/CBeaconMap.h>
-#include <mrpt/slam/CObservationBeaconRanges.h>
+#include <mrpt/maps/CBeaconMap.h>
+#include <mrpt/obs/CObservationBeaconRanges.h>
 #include <mrpt/random.h>
 #include <mrpt/utils/CFileOutputStream.h>
 #include <mrpt/utils/CConfigFileBase.h>
@@ -28,7 +28,9 @@
 #include <mrpt/opengl/stock_objects.h>
 
 using namespace mrpt;
-using namespace mrpt::slam;
+using namespace mrpt::maps;
+using namespace mrpt::math;
+using namespace mrpt::obs;
 using namespace mrpt::utils;
 using namespace mrpt::random;
 using namespace mrpt::poses;
@@ -36,7 +38,43 @@ using namespace mrpt::bayes;
 using namespace mrpt::system;
 using namespace std;
 
-IMPLEMENTS_SERIALIZABLE(CBeaconMap, CMetricMap,mrpt::slam)
+//  =========== Begin of Map definition ============
+MAP_DEFINITION_REGISTER("CBeaconMap,beaconMap", mrpt::maps::CBeaconMap)
+
+CBeaconMap::TMapDefinition::TMapDefinition()
+{
+}
+
+void CBeaconMap::TMapDefinition::loadFromConfigFile_map_specific(const mrpt::utils::CConfigFileBase  &source, const std::string &sectionNamePrefix)
+{
+	// [<sectionNamePrefix>+"_creationOpts"]
+	//const std::string sSectCreation = sectionNamePrefix+string("_creationOpts");
+	//MRPT_LOAD_CONFIG_VAR(resolution, float,   source,sSectCreation);
+
+	insertionOpts.loadFromConfigFile(source, sectionNamePrefix+string("_insertOpts") );
+	likelihoodOpts.loadFromConfigFile(source, sectionNamePrefix+string("_likelihoodOpts") );
+}
+
+void CBeaconMap::TMapDefinition::dumpToTextStream_map_specific(mrpt::utils::CStream &out) const
+{
+	//LOADABLEOPTS_DUMP_VAR(resolution     , float);
+
+	this->insertionOpts.dumpToTextStream(out);
+	this->likelihoodOpts.dumpToTextStream(out);
+}
+
+mrpt::maps::CMetricMap* CBeaconMap::internal_CreateFromMapDefinition(const mrpt::maps::TMetricMapInitializer &_def)
+{
+	const CBeaconMap::TMapDefinition &def = *dynamic_cast<const CBeaconMap::TMapDefinition*>(&_def);
+	CBeaconMap *obj = new CBeaconMap();
+	obj->insertionOptions  = def.insertionOpts;
+	obj->likelihoodOptions = def.likelihoodOpts;
+	return obj;
+}
+//  =========== End of Map definition Block =========
+
+
+IMPLEMENTS_SERIALIZABLE(CBeaconMap, CMetricMap,mrpt::maps)
 
 /*---------------------------------------------------------------
 						Constructor
@@ -77,17 +115,17 @@ void CBeaconMap::resize(const size_t N)
    Implements the writing to a CStream capability of
      CSerializable objects
   ---------------------------------------------------------------*/
-void  CBeaconMap::writeToStream(CStream &out, int *version) const
+void  CBeaconMap::writeToStream(mrpt::utils::CStream &out, int *version) const
 {
 	if (version)
-		*version = 0;
+		*version = 1;
 	else
 	{
-		uint32_t n = m_beacons.size();
+		out << genericMapParams; // v1
 
 		// First, write the number of landmarks:
+		const uint32_t n = m_beacons.size();
 		out << n;
-
 		// Write all landmarks:
 		for (const_iterator	it=begin();it!=end();++it)
 			out << (*it);
@@ -100,27 +138,26 @@ void  CBeaconMap::writeToStream(CStream &out, int *version) const
    Implements the reading from a CStream capability of
       CSerializable objects
   ---------------------------------------------------------------*/
-void  CBeaconMap::readFromStream(CStream &in, int version)
+void  CBeaconMap::readFromStream(mrpt::utils::CStream &in, int version)
 {
 	switch(version)
 	{
 	case 0:
+	case 1:
 		{
+			if (version>=1)
+				in >> genericMapParams; // v1
+
 			uint32_t	n,i;
 
 			// Delete previous content of map:
-			// -------------------------------------
 			clear();
 
 			// Load from stream:
-			// -------------------------------------
-			in >> n;
-
-			m_beacons.resize(n);
-
 			// Read all landmarks:
-			for (i=0;i<n;i++)
-				in >> m_beacons[i];
+			in >> n;
+			m_beacons.resize(n);
+			for (i=0;i<n;i++) in >> m_beacons[i];
 
 		} break;
 	default:
@@ -132,7 +169,7 @@ void  CBeaconMap::readFromStream(CStream &in, int version)
 /*---------------------------------------------------------------
 					computeObservationLikelihood
   ---------------------------------------------------------------*/
-double	 CBeaconMap::computeObservationLikelihood(
+double	 CBeaconMap::internal_computeObservationLikelihood(
 				const CObservation	*obs,
 				const CPose3D		&robotPose3D )
 {
@@ -162,7 +199,7 @@ double	 CBeaconMap::computeObservationLikelihood(
 		const CBeacon													*beac;
 		CPoint3D														sensor3D;
 
-		for (it_obs = o->sensedData.begin();it_obs!=o->sensedData.end();it_obs++)
+		for (it_obs = o->sensedData.begin();it_obs!=o->sensedData.end();++it_obs)
 		{
 			// Look for the beacon in this map:
 			beac=getBeaconByID( it_obs->beaconID );
@@ -191,7 +228,7 @@ double	 CBeaconMap::computeObservationLikelihood(
 						CVectorDouble				logLiks(beac->m_locationMC.m_particles.size());
 						CVectorDouble::iterator 	itLW,itLL;
 
-						for (it=beac->m_locationMC.m_particles.begin(),itLW=logWeights.begin(),itLL=logLiks.begin();it!=beac->m_locationMC.m_particles.end();it++,itLW++,itLL++)
+						for (it=beac->m_locationMC.m_particles.begin(),itLW=logWeights.begin(),itLL=logLiks.begin();it!=beac->m_locationMC.m_particles.end();++it,++itLW,++itLL)
 						{
 							float	expectedRange = sensor3D.distance3DTo( it->d->x,it->d->y,it->d->z );
 							//expectedRange += float(0.1*(1-exp(-0.16*expectedRange)));
@@ -246,7 +283,7 @@ double	 CBeaconMap::computeObservationLikelihood(
 						CVectorDouble::iterator 	itLW,itLL;
 						CPointPDFSOG::const_iterator it;
 						// For each Gaussian mode:
-						for (it=beac->m_locationSOG.begin(),itLW=logWeights.begin(),itLL=logLiks.begin();it!=beac->m_locationSOG.end();it++,itLW++,itLL++)
+						for (it=beac->m_locationSOG.begin(),itLW=logWeights.begin(),itLL=logLiks.begin();it!=beac->m_locationSOG.end();++it,++itLW,++itLL)
 						{
 							// Compute the Jacobian H and varZ
 							double varZ, varR = square( likelihoodOptions.rangeStd );
@@ -306,7 +343,7 @@ double	 CBeaconMap::computeObservationLikelihood(
 /*---------------------------------------------------------------
 						insertObservation
   ---------------------------------------------------------------*/
-bool  CBeaconMap::internal_insertObservation( const CObservation *obs, const CPose3D *robotPose)
+bool  CBeaconMap::internal_insertObservation( const mrpt::obs::CObservation *obs, const CPose3D *robotPose)
 {
 	MRPT_START
 
@@ -411,11 +448,10 @@ bool  CBeaconMap::internal_insertObservation( const CObservation *obs, const CPo
 					// ------------------------------
 					case CBeacon::pdfMonteCarlo:
 						{
-							CPointPDFParticles::CParticleList::iterator		it,it2;
 							double		maxW = -1e308, sumW=0;
 							// Update weights:
 							// --------------------
-							for (it=beac->m_locationMC.m_particles.begin();it!=beac->m_locationMC.m_particles.end();it++)
+							for (CPointPDFParticles::CParticleList::iterator it=beac->m_locationMC.m_particles.begin();it!=beac->m_locationMC.m_particles.end();++it)
 							{
 								float	expectedRange = sensorPnt.distance3DTo( it->d->x,it->d->y,it->d->z );
 								// Add bias:
@@ -454,7 +490,7 @@ bool  CBeaconMap::internal_insertObservation( const CObservation *obs, const CPo
 
 									// AND, add a small noise:
 									CPointPDFParticles::CParticleList::iterator		itSample;
-									for (itSample=beac->m_locationMC.m_particles.begin();itSample!=beac->m_locationMC.m_particles.end();itSample++)
+									for (itSample=beac->m_locationMC.m_particles.begin();itSample!=beac->m_locationMC.m_particles.end();++itSample)
 									{
 										itSample->d->x += randomGenerator.drawGaussian1D( 0,noiseStd );
 										itSample->d->y += randomGenerator.drawGaussian1D( 0,noiseStd );
@@ -478,7 +514,7 @@ bool  CBeaconMap::internal_insertObservation( const CObservation *obs, const CPo
 										delete it->d; it->d=NULL;
 										it = beac->m_locationMC.m_particles.erase( it );
 									}
-									else it++;
+									else ++it;
 								}
 							} // end "do not resample"
 
@@ -487,7 +523,7 @@ bool  CBeaconMap::internal_insertObservation( const CObservation *obs, const CPo
 							//  log_w -= log(sumW);
 							// -----------------------------------------
 							sumW=log(sumW);
-							for (it=beac->m_locationMC.m_particles.begin();it!=beac->m_locationMC.m_particles.end();it++)
+							for (CPointPDFParticles::CParticleList::iterator it=beac->m_locationMC.m_particles.begin();it!=beac->m_locationMC.m_particles.end();++it)
 								it->log_w -= sumW;
 
 							// Is the moment to turn into a Gaussian??
@@ -583,7 +619,7 @@ bool  CBeaconMap::internal_insertObservation( const CObservation *obs, const CPo
 							//  2) Update its mean/cov (as in the simple EKF)
 							CPointPDFSOG::iterator it;
 							double max_w = -1e9;
-							for (it=beac->m_locationSOG.begin();it!=beac->m_locationSOG.end();it++)
+							for (it=beac->m_locationSOG.begin();it!=beac->m_locationSOG.end();++it)
 							{
 								double 	expectedRange = sensorPnt.distanceTo( it->val.mean );
 
@@ -628,7 +664,7 @@ bool  CBeaconMap::internal_insertObservation( const CObservation *obs, const CPo
 									// Remove the mode:
 									it = beac->m_locationSOG.erase( it );
 								}
-								else it++;
+								else ++it;
 							}
 
 							//printf("ESS: %f\n",beac->m_locationSOG.ESS());
@@ -681,7 +717,7 @@ bool  CBeaconMap::internal_insertObservation( const CObservation *obs, const CPo
 				determineMatching2D
   ---------------------------------------------------------------*/
 void CBeaconMap::determineMatching2D(
-	const CMetricMap      * otherMap,
+	const mrpt::maps::CMetricMap      * otherMap,
 	const CPose2D         & otherMapPose,
 	TMatchingPairList     & correspondences,
 	const TMatchingParams & params,
@@ -725,7 +761,7 @@ void  CBeaconMap::changeCoordinatesReference( const CPose3D &newOrg )
 /*---------------------------------------------------------------
 				changeCoordinatesReference
   ---------------------------------------------------------------*/
-void  CBeaconMap::changeCoordinatesReference( const CPose3D &newOrg, const mrpt::slam::CBeaconMap *otherMap )
+void  CBeaconMap::changeCoordinatesReference( const CPose3D &newOrg, const mrpt::maps::CBeaconMap *otherMap )
 {
 	// In this object we cannot apply any special speed-up: Just copy and change coordinates:
 	(*this) = *otherMap;
@@ -737,7 +773,7 @@ void  CBeaconMap::changeCoordinatesReference( const CPose3D &newOrg, const mrpt:
 						computeMatchingWith3DLandmarks
   ---------------------------------------------------------------*/
 void  CBeaconMap::computeMatchingWith3DLandmarks(
-    const mrpt::slam::CBeaconMap						*anotherMap,
+    const mrpt::maps::CBeaconMap						*anotherMap,
     TMatchingPairList						&correspondences,
     float									&correspondencesRatio,
     vector<bool>						&otherCorrespondences) const
@@ -764,9 +800,9 @@ void  CBeaconMap::computeMatchingWith3DLandmarks(
 	otherCorrespondences.resize( nOther, false );
 	correspondencesRatio = 0;
 
-	for (k=0,otherIt=anotherMap->m_beacons.begin();otherIt!=anotherMap->m_beacons.end();otherIt++,k++)
+	for (k=0,otherIt=anotherMap->m_beacons.begin();otherIt!=anotherMap->m_beacons.end();++otherIt,++k)
 	{
-		for (j=0,thisIt=m_beacons.begin();thisIt!=m_beacons.end();thisIt++,j++)
+		for (j=0,thisIt=m_beacons.begin();thisIt!=m_beacons.end();++thisIt,++j)
 		{
 			// Is it a correspondence?
 			if ( (otherIt)->m_ID == (thisIt)->m_ID )
@@ -811,9 +847,9 @@ void  CBeaconMap::computeMatchingWith3DLandmarks(
 						saveToMATLABScript3D
   ---------------------------------------------------------------*/
 bool  CBeaconMap::saveToMATLABScript3D(
-						string		file,
-						const char		*style,
-						float			confInterval ) const
+	const string & file,
+	const char   *style,
+	float  confInterval ) const
 {
 	MRPT_UNUSED_PARAM(style);
 	MRPT_UNUSED_PARAM(confInterval);
@@ -861,7 +897,7 @@ CBeaconMap::TLikelihoodOptions::TLikelihoodOptions() :
 /*---------------------------------------------------------------
 					dumpToTextStream
   ---------------------------------------------------------------*/
-void  CBeaconMap::TLikelihoodOptions::dumpToTextStream(CStream	&out) const
+void  CBeaconMap::TLikelihoodOptions::dumpToTextStream(mrpt::utils::CStream	&out) const
 {
 	out.printf("\n----------- [CBeaconMap::TLikelihoodOptions] ------------ \n\n");
 
@@ -901,7 +937,7 @@ CBeaconMap::TInsertionOptions::TInsertionOptions() :
 /*---------------------------------------------------------------
 					dumpToTextStream
   ---------------------------------------------------------------*/
-void  CBeaconMap::TInsertionOptions::dumpToTextStream(CStream	&out) const
+void  CBeaconMap::TInsertionOptions::dumpToTextStream(mrpt::utils::CStream	&out) const
 {
 	out.printf("\n----------- [CBeaconMap::TInsertionOptions] ------------ \n\n");
 
@@ -959,7 +995,7 @@ void  CBeaconMap::simulateBeaconReadings(
     CObservationBeaconRanges        &out_Observations ) const
 {
 	TSequenceBeacons::const_iterator					    it;
-	mrpt::slam::CObservationBeaconRanges::TMeasurement	newMeas;
+	mrpt::obs::CObservationBeaconRanges::TMeasurement	newMeas;
 	CPoint3D										point3D,beacon3D;
 	CPointPDFGaussian								beaconPDF;
 
@@ -970,7 +1006,7 @@ void  CBeaconMap::simulateBeaconReadings(
 	out_Observations.sensedData.clear();
 
 	// For each BEACON landmark in the map:
-	for (it=m_beacons.begin();it!=m_beacons.end();it++)
+	for (it=m_beacons.begin();it!=m_beacons.end();++it)
 	{
 	    it->getMean(beacon3D);
 
@@ -1062,8 +1098,7 @@ void  CBeaconMap::getAs3DObject( mrpt::opengl::CSetOfObjectsPtr	&outObj ) const
 {
 	MRPT_START
 
-	if (m_disableSaveAs3DObject)
-		return;
+	if (!genericMapParams.enableSaveAs3DObject) return;
 
 	// ------------------------------------------------
 	//  Add the XYZ corner for the current area:
@@ -1089,7 +1124,7 @@ void  CBeaconMap::getAs3DObject( mrpt::opengl::CSetOfObjectsPtr	&outObj ) const
  * \sa computeMatchingWith2D
  ----------------------------------------------------------------*/
 float  CBeaconMap::compute3DMatchingRatio(
-    const CMetricMap								*otherMap2,
+    const mrpt::maps::CMetricMap								*otherMap2,
     const CPose3D							&otherMapPose,
     float									maxDistForCorr,
     float									maxMahaDistForCorr ) const
