@@ -39,6 +39,10 @@
 #	include <mrpt/utils/SSE_macros.h>
 #endif
 
+#if MRPT_HAS_MATLAB
+#	include <mexplus.h>
+#endif
+
 using namespace mrpt::poses;
 using namespace mrpt::maps;
 using namespace mrpt::utils;
@@ -182,6 +186,27 @@ bool  CPointsMap::load2Dor3D_from_text_file(
 }
 
 
+/*---------------------------------------------------------------
+  Implements the writing to a mxArray for Matlab
+ ---------------------------------------------------------------*/
+#if MRPT_HAS_MATLAB
+// Add to implement mexplus::from template specialization
+IMPLEMENTS_MEXPLUS_FROM( mrpt::maps::CPointsMap )
+
+mxArray* CPointsMap::writeToMatlab() const
+{
+	MRPT_TODO("Create 3xN array xyz of points coordinates")
+	const char* fields[] = {"x","y","z"};
+	mexplus::MxArray map_struct( mexplus::MxArray::Struct(sizeof(fields)/sizeof(fields[0]),fields) );
+
+	map_struct.set("x", this->x);
+	map_struct.set("y", this->y);
+	map_struct.set("z", this->z);
+	return map_struct.release();
+}
+#endif
+
+
 /*---------------------------------------------------------------
 					getPoint
 			Access to stored points coordinates:
@@ -960,9 +985,9 @@ void CPointsMap::boundingBox(
 				float *ptr_in_y = const_cast<float*>(&y[0]);
 				float *ptr_in_z = const_cast<float*>(&z[0]);
 				for (size_t k=nExtraPad;k; k--) {
-					ptr_in_x[nPoints+k]=0;
-					ptr_in_y[nPoints+k]=0;
-					ptr_in_z[nPoints+k]=0;
+					ptr_in_x[nPoints+k-1]=0;
+					ptr_in_y[nPoints+k-1]=0;
+					ptr_in_z[nPoints+k-1]=0;
 				}
 			}
 
