@@ -2,15 +2,15 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
 
 #include "maps-precomp.h" // Precomp header
 
-#include <mrpt/slam/CReflectivityGridMap2D.h>
-#include <mrpt/slam/CObservationReflectivity.h>
+#include <mrpt/maps/CReflectivityGridMap2D.h>
+#include <mrpt/obs/CObservationReflectivity.h>
 #include <mrpt/poses/CPose2D.h>
 #include <mrpt/utils/round.h> // round()
 #include <mrpt/system/os.h>
@@ -20,14 +20,60 @@
 
 
 using namespace mrpt;
-using namespace mrpt::slam;
+using namespace mrpt::maps;
+using namespace mrpt::obs;
 using namespace mrpt::poses;
 using namespace mrpt::math;
 using namespace mrpt::utils;
 using namespace mrpt::system;
 using namespace std;
 
-IMPLEMENTS_SERIALIZABLE(CReflectivityGridMap2D, CMetricMap,mrpt::slam)
+//  =========== Begin of Map definition ============
+MAP_DEFINITION_REGISTER("CReflectivityGridMap2D,reflectivityMap", mrpt::maps::CReflectivityGridMap2D)
+
+CReflectivityGridMap2D::TMapDefinition::TMapDefinition() :
+	min_x(-10.0f),
+	max_x(10.0f),
+	min_y(-10.0f),
+	max_y(10.0f),
+	resolution(0.10f)
+{
+}
+
+void CReflectivityGridMap2D::TMapDefinition::loadFromConfigFile_map_specific(const mrpt::utils::CConfigFileBase  &source, const std::string &sectionNamePrefix)
+{
+	// [<sectionNamePrefix>+"_creationOpts"]
+	const std::string sSectCreation = sectionNamePrefix+string("_creationOpts");
+	MRPT_LOAD_CONFIG_VAR(min_x, float,   source,sSectCreation);
+	MRPT_LOAD_CONFIG_VAR(max_x, float,   source,sSectCreation);
+	MRPT_LOAD_CONFIG_VAR(min_y, float,   source,sSectCreation);
+	MRPT_LOAD_CONFIG_VAR(max_y, float,   source,sSectCreation);
+	MRPT_LOAD_CONFIG_VAR(resolution, float,   source,sSectCreation);
+
+	insertionOpts.loadFromConfigFile(source, sectionNamePrefix+string("_insertOpts") );
+}
+
+void CReflectivityGridMap2D::TMapDefinition::dumpToTextStream_map_specific(mrpt::utils::CStream &out) const
+{
+	LOADABLEOPTS_DUMP_VAR(min_x         , float);
+	LOADABLEOPTS_DUMP_VAR(max_x         , float);
+	LOADABLEOPTS_DUMP_VAR(min_y         , float);
+	LOADABLEOPTS_DUMP_VAR(max_y         , float);
+	LOADABLEOPTS_DUMP_VAR(resolution         , float);
+
+	this->insertionOpts.dumpToTextStream(out);
+}
+
+mrpt::maps::CMetricMap* CReflectivityGridMap2D::internal_CreateFromMapDefinition(const mrpt::maps::TMetricMapInitializer &_def)
+{
+	const CReflectivityGridMap2D::TMapDefinition &def = *dynamic_cast<const CReflectivityGridMap2D::TMapDefinition*>(&_def);
+	CReflectivityGridMap2D *obj = new CReflectivityGridMap2D(def.min_x,def.max_x,def.min_y,def.max_y,def.resolution);
+	obj->insertionOptions  = def.insertionOpts;
+	return obj;
+}
+//  =========== End of Map definition Block =========
+
+IMPLEMENTS_SERIALIZABLE(CReflectivityGridMap2D, CMetricMap,mrpt::maps)
 
 
 // Lookup tables for log-odds
@@ -137,7 +183,7 @@ bool  CReflectivityGridMap2D::internal_insertObservation(
 /*---------------------------------------------------------------
 						computeObservationLikelihood
   ---------------------------------------------------------------*/
-double	 CReflectivityGridMap2D::computeObservationLikelihood(
+double	 CReflectivityGridMap2D::internal_computeObservationLikelihood(
 	const CObservation		*obs,
 	const CPose3D			&takenFrom )
 {
@@ -172,10 +218,10 @@ double	 CReflectivityGridMap2D::computeObservationLikelihood(
 /*---------------------------------------------------------------
   Implements the writing to a CStream capability of CSerializable objects
  ---------------------------------------------------------------*/
-void  CReflectivityGridMap2D::writeToStream(CStream &out, int *version) const
+void  CReflectivityGridMap2D::writeToStream(mrpt::utils::CStream &out, int *version) const
 {
 	if (version)
-		*version = 0;
+		*version = 1;
 	else
 	{
 		// Save the dimensions of the grid:
@@ -192,17 +238,19 @@ void  CReflectivityGridMap2D::writeToStream(CStream &out, int *version) const
 		// Save the insertion options:
 		// out << insertionOptions.maxOccupancyUpdateCertainty;
 
+		out << genericMapParams; // v1
 	}
 }
 
 /*---------------------------------------------------------------
   Implements the reading from a CStream capability of CSerializable objects
  ---------------------------------------------------------------*/
-void  CReflectivityGridMap2D::readFromStream(CStream &in, int version)
+void  CReflectivityGridMap2D::readFromStream(mrpt::utils::CStream &in, int version)
 {
 	switch(version)
 	{
 	case 0:
+	case 1:
 		{
 			uint32_t	n,i,j;
 
@@ -222,6 +270,9 @@ void  CReflectivityGridMap2D::readFromStream(CStream &in, int version)
 			// Load the insertion options:
 			// in >> insertionOptions.maxOccupancyUpdateCertainty;
 
+			if (version>=1) 
+				in >> genericMapParams;
+
 		} break;
 	default:
 		MRPT_THROW_UNKNOWN_SERIALIZATION_VERSION(version)
@@ -240,7 +291,7 @@ CReflectivityGridMap2D::TInsertionOptions::TInsertionOptions()
 /*---------------------------------------------------------------
 					dumpToTextStream
   ---------------------------------------------------------------*/
-void  CReflectivityGridMap2D::TInsertionOptions::dumpToTextStream(CStream	&out) const
+void  CReflectivityGridMap2D::TInsertionOptions::dumpToTextStream(mrpt::utils::CStream	&out) const
 {
 	out.printf("\n----------- [CReflectivityGridMap2D::TInsertionOptions] ------------ \n\n");
 
@@ -267,8 +318,6 @@ void  CReflectivityGridMap2D::TInsertionOptions::loadFromConfigFile(
 void  CReflectivityGridMap2D::saveMetricMapRepresentationToFile(
 	const std::string	&filNamePrefix ) const
 {
-	std::string		fil;
-
 	// Text matrix:
 	saveToTextFile( filNamePrefix + std::string("_probability.txt") );
 }
@@ -324,8 +373,7 @@ void  CReflectivityGridMap2D::getAsImage(
 ---------------------------------------------------------------*/
 void  CReflectivityGridMap2D::getAs3DObject( mrpt::opengl::CSetOfObjectsPtr	&outSetOfObj ) const
 {
-	if (m_disableSaveAs3DObject)
-		return;
+	if (!genericMapParams.enableSaveAs3DObject) return;
 
 	MRPT_START
 
@@ -362,7 +410,7 @@ void  CReflectivityGridMap2D::getAs3DObject( mrpt::opengl::CSetOfObjectsPtr	&out
 }
 
 float  CReflectivityGridMap2D::compute3DMatchingRatio(
-	const CMetricMap						*otherMap,
+	const mrpt::maps::CMetricMap						*otherMap,
 	const CPose3D							&otherMapPose,
 	float									maxDistForCorr,
 	float									maxMahaDistForCorr
