@@ -2,26 +2,57 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
 
 #include "maps-precomp.h" // Precomp header
 
-#include <mrpt/slam/CWeightedPointsMap.h>
+#include <mrpt/maps/CWeightedPointsMap.h>
 #include <mrpt/utils/CStream.h>
 
 #include "CPointsMap_crtp_common.h"
 
 using namespace std;
 using namespace mrpt;
-using namespace mrpt::slam;
+using namespace mrpt::maps;
+using namespace mrpt::obs;
 using namespace mrpt::utils;
 using namespace mrpt::poses;
 using namespace mrpt::math;
 
-IMPLEMENTS_SERIALIZABLE(CWeightedPointsMap, CPointsMap,mrpt::slam)
+//  =========== Begin of Map definition ============
+MAP_DEFINITION_REGISTER("CWeightedPointsMap,weightedPointsMap", mrpt::maps::CWeightedPointsMap)
+
+CWeightedPointsMap::TMapDefinition::TMapDefinition()
+{
+}
+
+void CWeightedPointsMap::TMapDefinition::loadFromConfigFile_map_specific(const mrpt::utils::CConfigFileBase  &source, const std::string &sectionNamePrefix)
+{
+	insertionOpts.loadFromConfigFile(source, sectionNamePrefix+string("_insertOpts") );
+	likelihoodOpts.loadFromConfigFile(source, sectionNamePrefix+string("_likelihoodOpts") );
+}
+
+void CWeightedPointsMap::TMapDefinition::dumpToTextStream_map_specific(mrpt::utils::CStream &out) const
+{
+	this->insertionOpts.dumpToTextStream(out);
+	this->likelihoodOpts.dumpToTextStream(out);
+}
+
+mrpt::maps::CMetricMap* CWeightedPointsMap::internal_CreateFromMapDefinition(const mrpt::maps::TMetricMapInitializer &_def)
+{
+	const CWeightedPointsMap::TMapDefinition &def = *dynamic_cast<const CWeightedPointsMap::TMapDefinition*>(&_def);
+	CWeightedPointsMap *obj = new CWeightedPointsMap();
+	obj->insertionOptions  = def.insertionOpts;
+	obj->likelihoodOptions = def.likelihoodOpts;
+	return obj;
+}
+//  =========== End of Map definition Block =========
+
+
+IMPLEMENTS_SERIALIZABLE(CWeightedPointsMap, CPointsMap,mrpt::maps)
 
 
 /*---------------------------------------------------------------
@@ -124,10 +155,10 @@ void  CWeightedPointsMap::addFrom_classSpecific(const CPointsMap &anotherMap, co
    Implements the writing to a CStream capability of
      CSerializable objects
   ---------------------------------------------------------------*/
-void  CWeightedPointsMap::writeToStream(CStream &out, int *version) const
+void  CWeightedPointsMap::writeToStream(mrpt::utils::CStream &out, int *version) const
 {
 	if (version)
-		*version = 1;
+		*version = 2;
 	else
 	{
 		uint32_t n = x.size();
@@ -143,7 +174,7 @@ void  CWeightedPointsMap::writeToStream(CStream &out, int *version) const
 			out.WriteBufferFixEndianness(&pointWeight[0],n);
 		}
 
-		out << m_disableSaveAs3DObject; // Insertion as 3D
+		out << genericMapParams; // v2
 		insertionOptions.writeToStream(out); // version 9: insert options are saved with its own method
 		likelihoodOptions.writeToStream(out); // Added in version 5
 	}
@@ -154,12 +185,13 @@ void  CWeightedPointsMap::writeToStream(CStream &out, int *version) const
    Implements the reading from a CStream capability of
       CSerializable objects
   ---------------------------------------------------------------*/
-void  CWeightedPointsMap::readFromStream(CStream &in, int version)
+void  CWeightedPointsMap::readFromStream(mrpt::utils::CStream &in, int version)
 {
 	switch(version)
 	{
 	case 0:
 	case 1:
+	case 2:
 		{
 			mark_as_modified();
 
@@ -183,7 +215,15 @@ void  CWeightedPointsMap::readFromStream(CStream &in, int version)
 
 			if (version>=1)
 			{
-				in >> m_disableSaveAs3DObject; // Insertion as 3D
+				if (version>=2)
+					in >> genericMapParams;
+				else 
+				{
+					bool disableSaveAs3DObject;
+					in >> disableSaveAs3DObject;
+					genericMapParams.enableSaveAs3DObject = !disableSaveAs3DObject;
+				}
+
 				insertionOptions.readFromStream(in); // version 9: insert options are saved with its own method
 			}
 			else
@@ -195,9 +235,13 @@ void  CWeightedPointsMap::readFromStream(CStream &in, int version)
 					>> insertionOptions.disableDeletion
 					>> insertionOptions.fuseWithExisting
 					>> insertionOptions.isPlanarMap
-					>> insertionOptions.maxDistForInterpolatePoints
-					>> m_disableSaveAs3DObject
-					>> insertionOptions.horizontalTolerance;
+					>> insertionOptions.maxDistForInterpolatePoints;
+				{
+					bool disableSaveAs3DObject;
+					in >> disableSaveAs3DObject;
+					genericMapParams.enableSaveAs3DObject = !disableSaveAs3DObject;
+				}
+				in >> insertionOptions.horizontalTolerance;
 			}
 
 			likelihoodOptions.readFromStream(in); // Added in version 5
@@ -225,19 +269,19 @@ void  CWeightedPointsMap::internal_clear()
 }
 
 namespace mrpt {
-	namespace slam {
+	namespace maps {
 		namespace detail {
-			using mrpt::slam::CWeightedPointsMap;
+			using mrpt::maps::CWeightedPointsMap;
 
 			template <> struct pointmap_traits<CWeightedPointsMap>
 			{
 				/** Helper method fot the generic implementation of CPointsMap::loadFromRangeScan(), to be called only once before inserting points - this is the place to reserve memory in lric for extra working variables. */
-				inline static void  internal_loadFromRangeScan2D_init(CWeightedPointsMap &me, mrpt::slam::CPointsMap::TLaserRange2DInsertContext & lric)  {
+				inline static void  internal_loadFromRangeScan2D_init(CWeightedPointsMap &me, mrpt::maps::CPointsMap::TLaserRange2DInsertContext & lric)  {
 					MRPT_UNUSED_PARAM(me);
 					MRPT_UNUSED_PARAM(lric);
 				}
 				/** Helper method fot the generic implementation of CPointsMap::loadFromRangeScan(), to be called once per range data */
-				inline static void  internal_loadFromRangeScan2D_prepareOneRange(CWeightedPointsMap &me, const float gx,const float gy, const float gz, mrpt::slam::CPointsMap::TLaserRange2DInsertContext & lric )  {
+				inline static void  internal_loadFromRangeScan2D_prepareOneRange(CWeightedPointsMap &me, const float gx,const float gy, const float gz, mrpt::maps::CPointsMap::TLaserRange2DInsertContext & lric )  {
 					MRPT_UNUSED_PARAM(me);
 					MRPT_UNUSED_PARAM(gx);
 					MRPT_UNUSED_PARAM(gy);
@@ -245,18 +289,18 @@ namespace mrpt {
 					MRPT_UNUSED_PARAM(lric);
 				}
 				/** Helper method fot the generic implementation of CPointsMap::loadFromRangeScan(), to be called after each "{x,y,z}.push_back(...);" */
-				inline static void  internal_loadFromRangeScan2D_postPushBack(CWeightedPointsMap &me, mrpt::slam::CPointsMap::TLaserRange2DInsertContext & lric)  {
+				inline static void  internal_loadFromRangeScan2D_postPushBack(CWeightedPointsMap &me, mrpt::maps::CPointsMap::TLaserRange2DInsertContext & lric)  {
 					MRPT_UNUSED_PARAM(lric);
 					me.pointWeight.push_back(1);
 				}
 
 				/** Helper method fot the generic implementation of CPointsMap::loadFromRangeScan(), to be called only once before inserting points - this is the place to reserve memory in lric for extra working variables. */
-				inline static void  internal_loadFromRangeScan3D_init(CWeightedPointsMap &me, mrpt::slam::CPointsMap::TLaserRange3DInsertContext & lric) {
+				inline static void  internal_loadFromRangeScan3D_init(CWeightedPointsMap &me, mrpt::maps::CPointsMap::TLaserRange3DInsertContext & lric) {
 					MRPT_UNUSED_PARAM(me);
 					MRPT_UNUSED_PARAM(lric);
 				}
 				/** Helper method fot the generic implementation of CPointsMap::loadFromRangeScan(), to be called once per range data */
-				inline static void  internal_loadFromRangeScan3D_prepareOneRange(CWeightedPointsMap &me, const float gx,const float gy, const float gz, mrpt::slam::CPointsMap::TLaserRange3DInsertContext & lric )  {
+				inline static void  internal_loadFromRangeScan3D_prepareOneRange(CWeightedPointsMap &me, const float gx,const float gy, const float gz, mrpt::maps::CPointsMap::TLaserRange3DInsertContext & lric )  {
 					MRPT_UNUSED_PARAM(me);
 					MRPT_UNUSED_PARAM(gx);
 					MRPT_UNUSED_PARAM(gy);
@@ -264,12 +308,12 @@ namespace mrpt {
 					MRPT_UNUSED_PARAM(lric);
 				}
 				/** Helper method fot the generic implementation of CPointsMap::loadFromRangeScan(), to be called after each "{x,y,z}.push_back(...);" */
-				inline static void  internal_loadFromRangeScan3D_postPushBack(CWeightedPointsMap &me, mrpt::slam::CPointsMap::TLaserRange3DInsertContext & lric)  {
+				inline static void  internal_loadFromRangeScan3D_postPushBack(CWeightedPointsMap &me, mrpt::maps::CPointsMap::TLaserRange3DInsertContext & lric)  {
 					MRPT_UNUSED_PARAM(lric);
 					me.pointWeight.push_back(1);
 				}
 				/** Helper method fot the generic implementation of CPointsMap::loadFromRangeScan(), to be called once per range data, at the end */
-				inline static void  internal_loadFromRangeScan3D_postOneRange(CWeightedPointsMap &me, mrpt::slam::CPointsMap::TLaserRange3DInsertContext & lric )  {
+				inline static void  internal_loadFromRangeScan3D_postOneRange(CWeightedPointsMap &me, mrpt::maps::CPointsMap::TLaserRange3DInsertContext & lric )  {
 					MRPT_UNUSED_PARAM(me);
 					MRPT_UNUSED_PARAM(lric);
 				}
@@ -284,7 +328,7 @@ void  CWeightedPointsMap::loadFromRangeScan(
 		const CObservation2DRangeScan &rangeScan,
 		const CPose3D				  *robotPose)
 {
-	mrpt::slam::detail::loadFromRangeImpl<CWeightedPointsMap>::templ_loadFromRangeScan(*this,rangeScan,robotPose);
+	mrpt::maps::detail::loadFromRangeImpl<CWeightedPointsMap>::templ_loadFromRangeScan(*this,rangeScan,robotPose);
 }
 
 /** See CPointsMap::loadFromRangeScan() */
@@ -292,7 +336,7 @@ void  CWeightedPointsMap::loadFromRangeScan(
 		const CObservation3DRangeScan &rangeScan,
 		const CPose3D				  *robotPose)
 {
-	mrpt::slam::detail::loadFromRangeImpl<CWeightedPointsMap>::templ_loadFromRangeScan(*this,rangeScan,robotPose);
+	mrpt::maps::detail::loadFromRangeImpl<CWeightedPointsMap>::templ_loadFromRangeScan(*this,rangeScan,robotPose);
 }
 
 
