@@ -2,23 +2,23 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
 
 #include "obs-precomp.h"   // Precompiled headers
 
-#include <mrpt/slam/CAction.h>
+#include <mrpt/obs/CAction.h>
 #include <mrpt/utils/CStream.h>
 #include <mrpt/utils/CStartUpClassesRegister.h>
 
 
-using namespace mrpt::slam;
+using namespace mrpt::obs;
 using namespace mrpt::utils;
 
 
-IMPLEMENTS_VIRTUAL_SERIALIZABLE(CAction, CSerializable, mrpt::slam)
+IMPLEMENTS_VIRTUAL_SERIALIZABLE(CAction, CSerializable, mrpt::obs)
 
 
 extern CStartUpClassesRegister  mrpt_obs_class_reg;
