@@ -2,14 +2,14 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
 
 #include "obs-precomp.h"   // Precompiled headers
 
-#include <mrpt/slam/CActionRobotMovement2D.h>
+#include <mrpt/obs/CActionRobotMovement2D.h>
 #include <mrpt/utils/CStream.h>
 #include <mrpt/poses/CPosePDFGaussian.h>
 #include <mrpt/poses/CPosePDFParticles.h>
@@ -17,13 +17,14 @@
 #include <mrpt/math/point_poses2vectors.h>
 #include <mrpt/math/wrap2pi.h>
 
-using namespace mrpt::slam;
+using namespace mrpt::obs;
 using namespace mrpt::utils;
 using namespace mrpt::poses;
+using namespace mrpt::math;
 using namespace mrpt::random;
 using namespace std;
 
-IMPLEMENTS_SERIALIZABLE(CActionRobotMovement2D, CAction, mrpt::slam)
+IMPLEMENTS_SERIALIZABLE(CActionRobotMovement2D, CAction, mrpt::obs)
 
 /*---------------------------------------------------------------
 						Constructor
@@ -87,7 +88,7 @@ CActionRobotMovement2D::~CActionRobotMovement2D()
 /*---------------------------------------------------------------
   Implements the writing to a CStream capability of CSerializable objects
  ---------------------------------------------------------------*/
-void  CActionRobotMovement2D::writeToStream(CStream &out, int *version) const
+void  CActionRobotMovement2D::writeToStream(mrpt::utils::CStream &out, int *version) const
 {
 	if (version)
 		*version = 6;
@@ -140,7 +141,7 @@ void  CActionRobotMovement2D::writeToStream(CStream &out, int *version) const
 /*---------------------------------------------------------------
   Implements the reading from a CStream capability of CSerializable objects
  ---------------------------------------------------------------*/
-void  CActionRobotMovement2D::readFromStream(CStream &in, int version)
+void  CActionRobotMovement2D::readFromStream(mrpt::utils::CStream &in, int version)
 {
 	switch(version)
 	{
