@@ -127,7 +127,7 @@ void  CObservationBeaconRanges::debugPrintOut()
  ---------------------------------------------------------------*/
 void CObservationBeaconRanges::getSensorPose( CPose3D &out_sensorPose ) const
 {
-	if (sensedData.size())
+	if (!sensedData.empty())
 		out_sensorPose=sensedData[0].sensorLocationOnRobot;
 	else 	out_sensorPose = CPose3D(0,0,0);
 }
