@@ -2,26 +2,27 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
 
 #include "obs-precomp.h"   // Precompiled headers
 
-#include <mrpt/slam/CObservationGPS.h>
+#include <mrpt/obs/CObservationGPS.h>
 #include <mrpt/utils/CStdOutStream.h>
 #include <mrpt/utils/CStream.h>
 #include <mrpt/math/matrix_serialization.h> // for << of matrices
+#include <mrpt/utils/CMemoryStream.h>
 
 using namespace std;
 using namespace mrpt;
 using namespace mrpt::utils;
-using namespace mrpt::slam;
+using namespace mrpt::obs;
 using namespace mrpt::math;
 
 // This must be added to any CSerializable class implementation file.
-IMPLEMENTS_SERIALIZABLE(CObservationGPS, CObservation,mrpt::slam)
+IMPLEMENTS_SERIALIZABLE(CObservationGPS, CObservation,mrpt::obs)
 
 CStdOutStream	gps_my_cout;
 
@@ -43,7 +44,7 @@ CObservationGPS::CObservationGPS( ) :
 /*---------------------------------------------------------------
   Implements the writing to a CStream capability of CSerializable objects
  ---------------------------------------------------------------*/
-void  CObservationGPS::writeToStream(CStream &out, int *version) const
+void  CObservationGPS::writeToStream(mrpt::utils::CStream &out, int *version) const
 {
 	MRPT_UNUSED_PARAM(out);
 	if (version)
@@ -132,7 +133,7 @@ void  CObservationGPS::writeToStream(CStream &out, int *version) const
 /*---------------------------------------------------------------
   Implements the reading from a CStream capability of CSerializable objects
  ---------------------------------------------------------------*/
-void  CObservationGPS::readFromStream(CStream &in, int version)
+void  CObservationGPS::readFromStream(mrpt::utils::CStream &in, int version)
 {
 	MRPT_UNUSED_PARAM(in);
 	switch(version)
@@ -281,7 +282,7 @@ void  CObservationGPS::readFromStream(CStream &in, int version)
 /*---------------------------------------------------------------
 					dumpToStream
  ---------------------------------------------------------------*/
-void  CObservationGPS::dumpToStream( CStream &out )
+void  CObservationGPS::dumpToStream( CStream &out ) const 
 {
 	out.printf("\n--------------------- [CObservationGPS] Dump: -----------------------\n");
 
@@ -413,15 +414,16 @@ void  CObservationGPS::dumpToStream( CStream &out )
 	out.printf("---------------------------------------------------------------------\n\n");
 }
 
-/*---------------------------------------------------------------
-					dumpToStream
- ---------------------------------------------------------------*/
-void  CObservationGPS::dumpToConsole()
+void  CObservationGPS::dumpToConsole(std::ostream &o) const
 {
-	dumpToStream( gps_my_cout );
+	mrpt::utils::CMemoryStream memStr;
+	this->dumpToStream( memStr );
+	
+	if (memStr.getTotalBytesCount()) {
+		o.write((const char*)memStr.getRawBufferData(),memStr.getTotalBytesCount());
+	}
 }
 
-
 // Ctor:
 CObservationGPS::TUTCTime::TUTCTime() :
 	hour(0), minute(0), sec(0)
@@ -502,3 +504,15 @@ mrpt::system::TTimeStamp CObservationGPS::TUTCTime::getAsTimestamp(const mrpt::s
 
     return buildTimestampFromParts(parts);
 }
+
+void CObservationGPS::getDescriptionAsText(std::ostream &o) const
+{
+	CObservation::getDescriptionAsText(o);
+
+	if (has_GGA_datum)
+		std::cout << std::endl << "Satellite time: " << format("%02u:%02u:%02.3f",GGA_datum.UTCTime.hour,GGA_datum.UTCTime.minute,GGA_datum.UTCTime.sec) << std::endl;
+
+	std::cout << "Sensor position on the robot: " << sensorPose << std::endl;
+
+	this->dumpToConsole();
+}
