@@ -2,19 +2,20 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
 
 #include "obs-precomp.h"   // Precompiled headers
 
-#include <mrpt/slam/CSimpleMap.h>
+#include <mrpt/maps/CSimpleMap.h>
 #include <mrpt/utils/CFileGZInputStream.h>
 #include <mrpt/utils/CFileGZOutputStream.h>
 #include <mrpt/utils/CStream.h>
 
-using namespace mrpt::slam;
+using namespace mrpt::obs;
+using namespace mrpt::maps;
 using namespace mrpt::utils;
 using namespace mrpt::poses;
 using namespace mrpt::poses;
@@ -23,7 +24,7 @@ using namespace std;
 #include <mrpt/utils/metaprogramming.h>
 using namespace mrpt::utils::metaprogramming;
 
-IMPLEMENTS_SERIALIZABLE(CSimpleMap, CSerializable,mrpt::slam)
+IMPLEMENTS_SERIALIZABLE(CSimpleMap, CSerializable,mrpt::maps)
 
 /*---------------------------------------------------------------
 						Constructor
@@ -257,7 +258,7 @@ void  CSimpleMap::insert(
 	Implements the writing to a CStream capability of
 	  CSerializable objects
   ---------------------------------------------------------------*/
-void  CSimpleMap::writeToStream(CStream &out,int *version) const
+void  CSimpleMap::writeToStream(mrpt::utils::CStream &out,int *version) const
 {
 	if (version)
 		*version = 1;
@@ -274,7 +275,7 @@ void  CSimpleMap::writeToStream(CStream &out,int *version) const
 /*---------------------------------------------------------------
 					readFromStream
   ---------------------------------------------------------------*/
-void  CSimpleMap::readFromStream(CStream &in, int version)
+void  CSimpleMap::readFromStream(mrpt::utils::CStream &in, int version)
 {
 	switch(version)
 	{
