@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -86,7 +86,7 @@ void   CAssimpModel::render_dl() const
    Implements the writing to a CStream capability of
      CSerializable objects
   ---------------------------------------------------------------*/
-void  CAssimpModel::writeToStream(CStream &out,int *version) const
+void  CAssimpModel::writeToStream(mrpt::utils::CStream &out,int *version) const
 {
 	if (version)
 		*version = 0;
@@ -114,7 +114,7 @@ void  CAssimpModel::writeToStream(CStream &out,int *version) const
 	Implements the reading from a CStream capability of
 		CSerializable objects
   ---------------------------------------------------------------*/
-void  CAssimpModel::readFromStream(CStream &in,int version)
+void  CAssimpModel::readFromStream(mrpt::utils::CStream &in,int version)
 {
 	THROW_EXCEPTION("MRPT can't serialize Assimp objects yet!")
 
@@ -520,7 +520,7 @@ void load_textures(
 		std::string filename = itr->first;  // get filename
 		CAssimpModel::TInfoPerTexture &ipt = itr->second;
 		ipt.id_idx =  i;	  // save texture id for filename in map
-		itr++; // next texture
+		++itr; // next texture
 
 		const std::string fileloc = mrpt::system::filePathSeparatorsToNative( basepath + filename );
 
