@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -16,6 +16,7 @@
 
 using namespace mrpt;
 using namespace mrpt::opengl;
+using namespace mrpt::math;
 using namespace mrpt::poses;
 using namespace mrpt::utils;
 
@@ -73,7 +74,7 @@ void COpenGLStandardObject::render_dl()	const	{
    Implements the writing to a CStream capability of
      CSerializable objects
   ---------------------------------------------------------------*/
-void COpenGLStandardObject::writeToStream(CStream &out,int *version) const	{
+void COpenGLStandardObject::writeToStream(mrpt::utils::CStream &out,int *version) const	{
 	if (version) *version=1;
 	else	{
 		writeToStreamRender(out);
@@ -85,7 +86,7 @@ void COpenGLStandardObject::writeToStream(CStream &out,int *version) const	{
 	Implements the reading from a CStream capability of
 		CSerializable objects
   ---------------------------------------------------------------*/
-void COpenGLStandardObject::readFromStream(CStream &in,int version)	{
+void COpenGLStandardObject::readFromStream(mrpt::utils::CStream &in,int version)	{
 	switch (version)	{
 		case 1:	{
 				readFromStreamRender(in);
@@ -120,3 +121,15 @@ void COpenGLStandardObject::getBoundingBox(mrpt::math::TPoint3D &bb_min, mrpt::m
 	m_pose.composePoint(bb_max, bb_max);
 }
 
+
+void COpenGLStandardObject::disable(_GLENUM flag) 
+{
+	std::vector<_GLENUM>::iterator it = enabled.begin();
+	while (it!=enabled.end())
+	{
+		if (*it==flag)
+				it = enabled.erase(it);
+		else ++it;
+	}
+	CRenderizableDisplayList::notifyChange();
+}
\ No newline at end of file
