@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -52,7 +52,7 @@ void   CSetOfObjects::render() const
    Implements the writing to a CStream capability of
      CSerializable objects
   ---------------------------------------------------------------*/
-void  CSetOfObjects::writeToStream(CStream &out,int *version) const
+void  CSetOfObjects::writeToStream(mrpt::utils::CStream &out,int *version) const
 {
 	if (version)
 		*version = 0;
@@ -72,7 +72,7 @@ void  CSetOfObjects::writeToStream(CStream &out,int *version) const
 	Implements the reading from a CStream capability of
 		CSerializable objects
   ---------------------------------------------------------------*/
-void  CSetOfObjects::readFromStream(CStream &in,int version)
+void  CSetOfObjects::readFromStream(mrpt::utils::CStream &in,int version)
 {
 
 	switch(version)
@@ -102,8 +102,7 @@ void  CSetOfObjects::initializeAllTextures()
 {
 #if MRPT_HAS_OPENGL_GLUT
 	CListOpenGLObjects::iterator it;
-	//deque<mrpt::opengl::CRenderizable*>::iterator it;
-	for (it=m_objects.begin();it!=m_objects.end();it++)
+	for (it=m_objects.begin();it!=m_objects.end();++it++)
 	{
 		if ( IS_DERIVED(*it, CTexturedObject ))
 			getAs<CTexturedObject>(*it)->loadTextureInOpenGL();
