@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -49,7 +49,7 @@ void   CSetOfTriangles::render_dl() const
 	glEnable(GL_NORMALIZE); // Normalize normals
 	glBegin(GL_TRIANGLES);
 
-	for (it=m_triangles.begin();it!=m_triangles.end();it++)
+	for (it=m_triangles.begin();it!=m_triangles.end();++it)
 	{
         // Compute the normal vector:
         // ---------------------------------
@@ -84,7 +84,7 @@ void   CSetOfTriangles::render_dl() const
    Implements the writing to a CStream capability of
      CSerializable objects
   ---------------------------------------------------------------*/
-void  CSetOfTriangles::writeToStream(CStream &out,int *version) const
+void  CSetOfTriangles::writeToStream(mrpt::utils::CStream &out,int *version) const
 {
 
 	if (version)
@@ -106,7 +106,7 @@ void  CSetOfTriangles::writeToStream(CStream &out,int *version) const
 	Implements the reading from a CStream capability of
 		CSerializable objects
   ---------------------------------------------------------------*/
-void  CSetOfTriangles::readFromStream(CStream &in,int version)
+void  CSetOfTriangles::readFromStream(mrpt::utils::CStream &in,int version)
 {
 	switch(version)
 	{
