@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -358,9 +358,9 @@ void gl_utils::renderMessageBox(
 	const float msg_w, const float msg_h,
 	const std::string &text,
 	float text_scale,
-	const mrpt::utils::TColor back_col,
-	const mrpt::utils::TColor border_col,
-	const mrpt::utils::TColor text_col,
+	const mrpt::utils::TColor &back_col,
+	const mrpt::utils::TColor &border_col,
+	const mrpt::utils::TColor &text_col,
 	const float border_width,
 	const std::string & text_font,
 	mrpt::opengl::TOpenGLFontStyle text_style,
