@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -13,11 +13,11 @@
 #include <mrpt/utils/CListOfClasses.h>
 #include <mrpt/utils/CDebugOutputCapable.h>
 #include <mrpt/synch.h>
-#include <mrpt/slam/CMultiMetricMap.h>
-#include <mrpt/slam/CSensoryFrame.h>
-#include <mrpt/slam/CSimpleMap.h>
+#include <mrpt/maps/CMultiMetricMap.h>
+#include <mrpt/obs/CSensoryFrame.h>
+#include <mrpt/maps/CSimpleMap.h>
 #include <mrpt/poses/CPose3DPDF.h>
-#include <mrpt/slam/CActionCollection.h>
+#include <mrpt/obs/CActionCollection.h>
 
 #include <mrpt/slam/link_pragmas.h>
 
@@ -57,27 +57,27 @@ namespace slam
 
 		/** Initialize the method, starting with a known location PDF "x0"(if supplied, set to NULL to left unmodified) and a given fixed, past map. */
 		virtual void  initialize(
-				const CSimpleMap &initialMap = CSimpleMap(),
-				CPosePDF					*x0 = NULL
-				) = 0;
+			const mrpt::maps::CSimpleMap &initialMap = mrpt::maps::CSimpleMap(),
+			mrpt::poses::CPosePDF *x0 = NULL
+			) = 0;
 
 		/** Returns a copy of the current best pose estimation as a pose PDF. */
-		virtual CPose3DPDFPtr  getCurrentPoseEstimation() const = 0;
+		virtual mrpt::poses::CPose3DPDFPtr  getCurrentPoseEstimation() const = 0;
 
 		/** Process a new action and observations pair to update this map: See the description of the class at the top of this page to see a more complete description.
 		 *  \param action The estimation of the incremental pose change in the robot pose.
 		 *	\param observations The set of observations that robot senses at the new pose.
 		 */
-		virtual void  processActionObservation( CActionCollection &action,CSensoryFrame	&observations ) = 0;
+		virtual void  processActionObservation( mrpt::obs::CActionCollection &action,mrpt::obs::CSensoryFrame	&observations ) = 0;
 
 		/** Fills "out_map" with the set of "poses"-"sensory-frames", thus the so far built map. */
-		virtual void  getCurrentlyBuiltMap(CSimpleMap &out_map) const = 0;
+		virtual void  getCurrentlyBuiltMap(mrpt::maps::CSimpleMap &out_map) const = 0;
 
 		/** Returns just how many sensory-frames are stored in the currently build map. */
 		virtual unsigned int  getCurrentlyBuiltMapSize() = 0;
 
 		/** Returns the map built so far. NOTE that for efficiency a pointer to the internal object is passed, DO NOT delete nor modify the object in any way, if desired, make a copy of ir with "duplicate()". */
-		virtual CMultiMetricMap*   getCurrentlyBuiltMetricMap() = 0;
+		virtual mrpt::maps::CMultiMetricMap*   getCurrentlyBuiltMetricMap() = 0;
 
 		/** A useful method for debugging: the current map (and/or poses) estimation is dumped to an image file.
 		  * \param file The output file name
@@ -97,10 +97,10 @@ namespace slam
 			options.enableMapUpdating = enable;
 		}
 
-		/** Load map (mrpt::slam::CSimpleMap) from a ".simplemap" file */
+		/** Load map (mrpt::maps::CSimpleMap) from a ".simplemap" file */
 		void  loadCurrentMapFromFile(const std::string &fileName);
 
-		/** Save map (mrpt::slam::CSimpleMap) to a ".simplemap" file. */
+		/** Save map (mrpt::maps::CSimpleMap) to a ".simplemap" file. */
 		void  saveCurrentMapToFile(const std::string &fileName, bool compressGZ=true) const;
 
 		/** Options for the algorithm */
@@ -117,7 +117,7 @@ namespace slam
 			bool	enableMapUpdating;   //!< Enable map updating, default is true.
 			bool	debugForceInsertion; //!< Always insert into map. Default is false: detect if necesary.
 
-			/** A list of observation classes (derived from mrpt::slam::CObservation) which will be always inserted in the map, disregarding the minimum insertion distances).
+			/** A list of observation classes (derived from mrpt::obs::CObservation) which will be always inserted in the map, disregarding the minimum insertion distances).
 			  *  Default: Empty. How to insert classes:
 			  *   \code
 			  *     alwaysInserByClass.insert(CLASS_ID(CObservationImage));
