@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -21,11 +21,11 @@ namespace mrpt
 namespace slam
 {
 	/** A class for very simple 2D SLAM based on ICP. This is a non-probabilistic pose tracking algorithm.
-	 *   Map are stored as in files as binary dumps of "mrpt::slam::CSimpleMap" objects. The methods are
+	 *   Map are stored as in files as binary dumps of "mrpt::maps::CSimpleMap" objects. The methods are
 	 *	 thread-safe.
 	 * \ingroup metric_slam_grp
 	 */
-	class SLAM_IMPEXP  CMetricMapBuilderICP : public CMetricMapBuilder
+	class SLAM_IMPEXP  CMetricMapBuilderICP : public mrpt::slam::CMetricMapBuilder
 	{
 	 public:
 		 /** Default constructor - Upon construction, you can set the parameters in ICP_options, then call "initialize".
@@ -45,7 +45,7 @@ namespace slam
 			 virtual void  loadFromConfigFile(
 				const mrpt::utils::CConfigFileBase	&source,
 				const std::string		&section);
-			 virtual void  dumpToTextStream( CStream		&out) const;
+			 virtual void  dumpToTextStream( mrpt::utils::CStream &out) const;
 
 			/** (default:false) Match against the occupancy grid or the points map? The former is quicker but less precise. */
 			bool	matchAgainstTheGrid;
@@ -60,7 +60,7 @@ namespace slam
 			/** What maps to create (at least one points map and/or a grid map are needed).
 			  *  For the expected format in the .ini file when loaded with loadFromConfigFile(), see documentation of TSetOfMetricMapInitializers.
 			  */
-			TSetOfMetricMapInitializers	mapInitializers;
+			mrpt::maps::TSetOfMetricMapInitializers	mapInitializers;
 
 		 };
 
@@ -71,13 +71,13 @@ namespace slam
 		  *  This method MUST be called if using the default constructor, after loading the configuration into ICP_options. In particular, TConfigParams::mapInitializers
 		  */
 		void  initialize(
-			const CSimpleMap &initialMap  = CSimpleMap(),
-			CPosePDF					*x0 = NULL
+			const mrpt::maps::CSimpleMap &initialMap  = mrpt::maps::CSimpleMap(),
+			mrpt::poses::CPosePDF *x0 = NULL
 			);
 
 		/** Returns a copy of the current best pose estimation as a pose PDF.
 		  */
-		CPose3DPDFPtr  getCurrentPoseEstimation() const;
+		mrpt::poses::CPose3DPDFPtr  getCurrentPoseEstimation() const;
 
 		 /** Sets the "current map file", thus that map will be loaded if it exists or a new one will be created if it does not, and the updated map will be save to that file when destroying the object.
 		   */
@@ -90,20 +90,20 @@ namespace slam
 		 * \sa processObservation
 		 */
 		void  processActionObservation(
-					CActionCollection	&action,
-					CSensoryFrame		&in_SF );
+			mrpt::obs::CActionCollection	&action,
+			mrpt::obs::CSensoryFrame		&in_SF );
 
 		/**  The main method of this class: Process one odometry or sensor observation.
 		    The new entry point of the algorithm (the old one  was processActionObservation, which now is a wrapper to
 		  this method).
 		 * See params in CMetricMapBuilder::options and CMetricMapBuilderICP::ICP_options
 		  */
-		void  processObservation(const CObservationPtr &obs);
+		void  processObservation(const mrpt::obs::CObservationPtr &obs);
 
 
 		/** Fills "out_map" with the set of "poses"-"sensory-frames", thus the so far built map.
 		  */
-		void  getCurrentlyBuiltMap(CSimpleMap &out_map) const;
+		void  getCurrentlyBuiltMap(mrpt::maps::CSimpleMap &out_map) const;
 
 
 		 /** Returns the 2D points of current local map
@@ -112,7 +112,7 @@ namespace slam
 
 		/** Returns the map built so far. NOTE that for efficiency a pointer to the internal object is passed, DO NOT delete nor modify the object in any way, if desired, make a copy of ir with "duplicate()".
 		  */
-		CMultiMetricMap*   getCurrentlyBuiltMetricMap();
+		mrpt::maps::CMultiMetricMap*   getCurrentlyBuiltMetricMap();
 
 		/** Returns just how many sensory-frames are stored in the currently build map.
 		  */
@@ -125,16 +125,13 @@ namespace slam
 		void  saveCurrentEstimationToImage(const std::string &file, bool formatEMF_BMP = true);
 
 	 private:
-		 /** The set of observations that leads to current map:
-		   */
-		 CSimpleMap		SF_Poses_seq;
+		 /** The set of observations that leads to current map: */
+		 mrpt::maps::CSimpleMap		SF_Poses_seq;
 
-		 /** The metric map representation as a points map:
-		   */
-		 CMultiMetricMap			metricMap;
+		 /** The metric map representation as a points map: */
+		 mrpt::maps::CMultiMetricMap			metricMap;
 
-		 /** Current map file.
-		   */
+		 /** Current map file. */
 		 std::string				currentMapFile;
 
 		 /** The pose estimation by the alignment algorithm (ICP). */
@@ -161,8 +158,8 @@ namespace slam
 		mrpt::aligned_containers<std::string,TDist>::map_t  m_distSinceLastInsertion; //!< Indexed by sensor label.
 		bool	 m_there_has_been_an_odometry;
 
-		void accumulateRobotDisplacementCounters(const CPose2D & new_pose);
-		void resetRobotDisplacementCounters(const CPose2D & new_pose);
+		void accumulateRobotDisplacementCounters(const mrpt::poses::CPose2D & new_pose);
+		void resetRobotDisplacementCounters(const mrpt::poses::CPose2D & new_pose);
 
 	};
 
