@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -12,9 +12,9 @@
 #if MRPT_ENABLE_PRECOMPILED_HDRS
 
 // Maps:
-#include <mrpt/slam/CMetricMap.h>
-#include <mrpt/slam/CObservation.h>
-#include <mrpt/slam/CSensoryFrame.h>
+#include <mrpt/maps/CMetricMap.h>
+#include <mrpt/obs/CObservation.h>
+#include <mrpt/obs/CSensoryFrame.h>
 
 #endif
 
