@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -10,7 +10,7 @@
 #include "slam-precomp.h"   // Precompiled headers
 
 #include <mrpt/slam/CIncrementalMapPartitioner.h>
-#include <mrpt/slam/CMultiMetricMap.h>
+#include <mrpt/maps/CMultiMetricMap.h>
 #include <mrpt/slam/observations_overlap.h>
 #include <mrpt/poses/CPosePDFParticles.h>
 #include <mrpt/poses/CPose3DPDFParticles.h>
@@ -23,9 +23,13 @@
 #include <mrpt/opengl/CSimpleLine.h>
 
 using namespace mrpt::slam;
+using namespace mrpt::obs;
+using namespace mrpt::maps;
+using namespace mrpt::math;
 using namespace mrpt::graphs;
 using namespace mrpt::poses;
 using namespace mrpt::utils;
+using namespace mrpt;
 using namespace std;
 
 IMPLEMENTS_SERIALIZABLE(CIncrementalMapPartitioner, CSerializable,mrpt::slam)
@@ -90,7 +94,7 @@ void  CIncrementalMapPartitioner::TOptions::loadFromConfigFile(
 /*---------------------------------------------------------------
 						dumpToTextStream
   ---------------------------------------------------------------*/
-void  CIncrementalMapPartitioner::TOptions::dumpToTextStream(CStream	&out) const
+void  CIncrementalMapPartitioner::TOptions::dumpToTextStream(mrpt::utils::CStream	&out) const
 {
 	out.printf("\n----------- [CIncrementalMapPartitioner::TOptions] ------------ \n\n");
 
@@ -115,7 +119,7 @@ void CIncrementalMapPartitioner::clear()
 	m_individualFrames.clear();	// Liberar el mapa hasta ahora:
 
 	// Free individual maps:
-	//for (deque_serializable<mrpt::slam::CMultiMetricMap>::iterator it=m_individualMaps.begin();it!=m_individualMaps.end();++it)	delete (*it);
+	//for (deque_serializable<mrpt::maps::CMultiMetricMap>::iterator it=m_individualMaps.begin();it!=m_individualMaps.end();++it)	delete (*it);
 	m_individualMaps.clear();
 
 	m_last_partition.clear();		// Borrar las ultimas particiones
@@ -147,34 +151,28 @@ unsigned int CIncrementalMapPartitioner::addMapFrame(
 	CPose3DPDFPtr						posePDF_i, posePDF_j;
 	CSensoryFramePtr					sf_i, sf_j;
 	CMultiMetricMap						*map_i=NULL,*map_j=NULL;
-	int									debug_CheckPoint = 0;
 	mrpt::utils::TMatchingPairList		corrs;
 	static CPose3D						nullPose(0,0,0);
 
 	// Create the maps:
 	TSetOfMetricMapInitializers			mapInitializer;
-	TMetricMapInitializer				mapElement;
 
-	mapElement.metricMapClassType = CLASS_ID( CSimplePointsMap );
-	mapInitializer.push_back( mapElement );
+	{
+		CSimplePointsMap::TMapDefinition def;
+		mapInitializer.push_back(def);
+	}
 
-//	mapElement.metricMapClassType = CLASS_ID( COccupancyGridMap2D );
-//	mapElement.occupancyGridMap2D_options.resolution = options.gridResolution;
-//	mapInitializer.push_back( mapElement );
-
-	mapElement.metricMapClassType = CLASS_ID( CLandmarksMap );
-//	mapElement.landmarksMap_options.insertionOpts.
-	mapInitializer.push_back( mapElement );
+	{
+		CLandmarksMap::TMapDefinition def;
+		mapInitializer.push_back(def);
+	}
 
 	// Add new metric map to "m_individualMaps"
 	// --------------------------------------------
-	//CMultiMetricMap			*newMetricMap = new CMultiMetricMap( &mapInitializer );
-
 	m_individualMaps.push_back( CMultiMetricMap() );
 	CMultiMetricMap		&newMetricMap = m_individualMaps.back();
 	newMetricMap.setListOfMaps( &mapInitializer );
 
-
 	MRPT_START
 
 	// Create the metric map:
@@ -191,27 +189,22 @@ unsigned int CIncrementalMapPartitioner::addMapFrame(
 	newMetricMap.m_pointsMaps[0]->copyFrom( * frame->buildAuxPointsMap<CPointsMap>(&newMetricMap.m_pointsMaps[0]->insertionOptions));	// Faster :-)
 
 	// Insert just the VisualLandmarkObservations:
-	newMetricMap.m_landmarksMap->insertionOptions.insert_SIFTs_from_monocular_images = false;
-	newMetricMap.m_landmarksMap->insertionOptions.insert_SIFTs_from_stereo_images    = false;
-	newMetricMap.m_landmarksMap->insertionOptions.insert_Landmarks_from_range_scans  = false;
-	frame->insertObservationsInto( newMetricMap.m_landmarksMap );
-
-	debug_CheckPoint=1;
+	mrpt::maps::CLandmarksMap &lm = *newMetricMap.m_landmarksMap;
+	lm.insertionOptions.insert_SIFTs_from_monocular_images = false;
+	lm.insertionOptions.insert_SIFTs_from_stereo_images    = false;
+	lm.insertionOptions.insert_Landmarks_from_range_scans  = false;
+	frame->insertObservationsInto( &lm );
 
 	// Add to corresponding vectors:
 	m_individualFrames.insert(robotPose, frame);
 	// Already added to "m_individualMaps" above
 
-	debug_CheckPoint=2;
-
 	// Ampliar la matriz de adyacencias:
 	// -----------------------------------------------------------------
 	n = m_A.getColCount();
 	n++;
 	m_A.setSize(n,n);
 
-	debug_CheckPoint=3;
-
 	ASSERT_(m_individualMaps.size() == n);
 	ASSERT_(m_individualFrames.size() == n);
 
@@ -226,8 +219,6 @@ unsigned int CIncrementalMapPartitioner::addMapFrame(
 	// ------------------------------------------------------------------------------
 	bool useMapOrSF = options.useMapMatching;
 
-	debug_CheckPoint=4;
-
 	// Calcular los nuevos matchings y meterlos en la matriz:
 	// ----------------------------------------------------------------
 	//for (i=n-1;i<n;i++)
@@ -240,24 +231,17 @@ unsigned int CIncrementalMapPartitioner::addMapFrame(
 		// And its points map:
 		map_i = &m_individualMaps[i];
 
-		debug_CheckPoint=5;
-
-//			for (j=0;j<n;j++)
 		for (j=0;j<n-1;j++)
 		{
 			// Get node "j":
 			m_individualFrames.get(j, posePDF_j, sf_j);
 			posePDF_j->getMean( pose_j );
 
-			debug_CheckPoint=6;
-
 			relPose = pose_j - pose_i;
 
 			// And its points map:
 			map_j = &m_individualMaps[j];
 
-			debug_CheckPoint=66;
-
 			// Compute matching ratio:
 			if (useMapOrSF)
 			{
@@ -280,8 +264,6 @@ unsigned int CIncrementalMapPartitioner::addMapFrame(
 
 	for (i=0;i<n-1;i++)  // Solo ejecutar para "i=n-1" la ultima fila/columna que esta vacia
 	{
-		debug_CheckPoint=8;
-
 		// Get node "i":
 		m_individualFrames.get(i, posePDF_i, sf_i);
 		posePDF_i->getMean(pose_i);
@@ -289,16 +271,12 @@ unsigned int CIncrementalMapPartitioner::addMapFrame(
 		// And its points map:
 		map_i = &m_individualMaps[i];
 
-		debug_CheckPoint=9;
-
 		j=n-1; //for (j=n-1;j<n;j++)
 		{
 			// Get node "j":
 			m_individualFrames.get(j, posePDF_j, sf_j);
 			posePDF_j->getMean(pose_j);
 
-			debug_CheckPoint=10;
-
 			relPose = pose_j - pose_i;
 
 			// And its points map:
@@ -318,15 +296,9 @@ unsigned int CIncrementalMapPartitioner::addMapFrame(
 				//m_A(i,j) = sf_i->likelihoodWith(sf_j.pointer());
 				m_A(i,j) = observationsOverlap(sf_i, sf_j, &relPose );
 			}
-
-			debug_CheckPoint=12;
-
 		} // for j
-
 	} // for i
 
-	debug_CheckPoint=13;
-
 	// Self-similatity: Not used
 	m_A(n-1,n-1) = 0;
 
@@ -336,8 +308,6 @@ unsigned int CIncrementalMapPartitioner::addMapFrame(
 		for (j=i+1;j<n;j++)
 			m_A(i,j) = m_A(j,i) = 0.5f * (m_A(i,j) + m_A(j,i) );
 
-	debug_CheckPoint=14;
-
 	/* DEBUG: Guardar la matriz: * /
 	A.saveToTextFile("debug_matriz.txt",1);
 	/ **/
@@ -347,8 +317,6 @@ unsigned int CIncrementalMapPartitioner::addMapFrame(
 	for (i=0;i<n;i++)
 		m_modified_nodes[i] = m_A(i,n-1) > 0;
 
-	debug_CheckPoint=15;
-
 	if (m_last_last_partition_are_new_ones)
 	{
 		// Insert into the "new_ones" partition:
@@ -368,7 +336,7 @@ unsigned int CIncrementalMapPartitioner::addMapFrame(
 	return n-1; // Index of the new node
 
 	MRPT_END_WITH_CLEAN_UP( \
-		cout << "Unexpected runtime error at checkPoint="<< debug_CheckPoint << "\n"; \
+		cout << "Unexpected runtime error:\n"; \
 		cout << "\tn=" << n << "\n"; \
 		cout << "\ti=" << i << "\n"; \
 		cout << "\tj=" << j << "\n"; \
@@ -576,7 +544,7 @@ void  CIncrementalMapPartitioner::removeSetOfNodes(vector_uint	indexesToRemove,
 	vector_uint::reverse_iterator it;
 	for (it= indexesToRemove.rbegin(); it!=indexesToRemove.rend(); ++it)
 	{
-		deque<mrpt::slam::CMultiMetricMap>::iterator  itM = m_individualMaps.begin() + *it;
+		deque<mrpt::maps::CMultiMetricMap>::iterator  itM = m_individualMaps.begin() + *it;
 		// delete *itM; // Delete map
 		m_individualMaps.erase( itM ); // Delete from list
 	}
@@ -717,7 +685,7 @@ void CIncrementalMapPartitioner::getAs3DScene(
 /*---------------------------------------------------------------
 					readFromStream
   ---------------------------------------------------------------*/
-void  CIncrementalMapPartitioner::readFromStream(CStream &in,int version)
+void  CIncrementalMapPartitioner::readFromStream(mrpt::utils::CStream &in,int version)
 {
 	switch(version)
 	{
@@ -741,7 +709,7 @@ void  CIncrementalMapPartitioner::readFromStream(CStream &in,int version)
 	Implements the writing to a CStream capability of
 	  CSerializable objects
   ---------------------------------------------------------------*/
-void  CIncrementalMapPartitioner::writeToStream(CStream &out, int *version) const
+void  CIncrementalMapPartitioner::writeToStream(mrpt::utils::CStream &out, int *version) const
 {
 	if (version)
 		*version = 0;
