@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -14,23 +14,26 @@
 #include <mrpt/utils/CTicTac.h>
 #include <mrpt/utils/CFileStream.h>
 
-#include <mrpt/slam/CMultiMetricMapPDF.h>
-#include <mrpt/slam/CActionRobotMovement2D.h>
-#include <mrpt/slam/CActionRobotMovement3D.h>
-#include <mrpt/slam/CActionCollection.h>
+#include <mrpt/maps/CMultiMetricMapPDF.h>
+#include <mrpt/obs/CActionRobotMovement2D.h>
+#include <mrpt/obs/CActionRobotMovement3D.h>
+#include <mrpt/obs/CActionCollection.h>
 #include <mrpt/poses/CPosePDFGaussian.h>
 #include <mrpt/poses/CPosePDFGrid.h>
-#include <mrpt/slam/CObservationBeaconRanges.h>
-#include <mrpt/slam/CSimplePointsMap.h>
-#include <mrpt/slam/CLandmarksMap.h>
+#include <mrpt/obs/CObservationBeaconRanges.h>
+#include <mrpt/maps/CSimplePointsMap.h>
+#include <mrpt/maps/CLandmarksMap.h>
 #include <mrpt/math.h>
 
 #include <mrpt/slam/PF_aux_structs.h>
 
 
 using namespace mrpt;
+using namespace mrpt::bayes;
 using namespace mrpt::math;
 using namespace mrpt::slam;
+using namespace mrpt::obs;
+using namespace mrpt::maps;
 using namespace mrpt::poses;
 using namespace mrpt::random;
 using namespace mrpt::utils;
@@ -46,7 +49,7 @@ namespace mrpt
 		void KLF_loadBinFromParticle(
 			detail::TPoseBin2D	&outBin,
 			const TKLDParams  	&opts,
-			const CRBPFParticleData	*currentParticleValue,
+			const mrpt::maps::CRBPFParticleData	*currentParticleValue,
 			const TPose3D			*newPoseToBeInserted)
 		{
 			// 2D pose approx: Use the latest pose only:
@@ -72,7 +75,7 @@ namespace mrpt
 		void KLF_loadBinFromParticle(
 			detail::TPathBin2D	&outBin,
 			const TKLDParams  	&opts,
-			const CRBPFParticleData	*currentParticleValue,
+			const mrpt::maps::CRBPFParticleData	*currentParticleValue,
 			const TPose3D			*newPoseToBeInserted)
 		{
 			const size_t lenBinPath = (currentParticleValue!=NULL) ? currentParticleValue->robotPath.size() : 0;
@@ -134,8 +137,8 @@ struct TAuxRangeMeasInfo
   See paper reference in "PF_SLAM_implementation_pfAuxiliaryPFOptimal"
  ----------------------------------------------------------------------------------*/
 void  CMultiMetricMapPDF::prediction_and_update_pfAuxiliaryPFOptimal(
-	const mrpt::slam::CActionCollection	* actions,
-	const mrpt::slam::CSensoryFrame		* sf,
+	const mrpt::obs::CActionCollection	* actions,
+	const mrpt::obs::CSensoryFrame		* sf,
 	const bayes::CParticleFilter::TParticleFilterOptions &PF_options )
 {
 	MRPT_START
@@ -163,8 +166,8 @@ For beacon maps:
 
  ----------------------------------------------------------------------------------*/
 void  CMultiMetricMapPDF::prediction_and_update_pfOptimalProposal(
-	const mrpt::slam::CActionCollection	* actions,
-	const mrpt::slam::CSensoryFrame		* sf,
+	const mrpt::obs::CActionCollection	* actions,
+	const mrpt::obs::CSensoryFrame		* sf,
 	const bayes::CParticleFilter::TParticleFilterOptions &PF_options )
 {
 	MRPT_START
@@ -850,8 +853,8 @@ void  CMultiMetricMapPDF::prediction_and_update_pfOptimalProposal(
 			prediction_and_update_pfStandardProposal
  ---------------------------------------------------------------*/
 void  CMultiMetricMapPDF::prediction_and_update_pfStandardProposal(
-	const mrpt::slam::CActionCollection	* actions,
-	const mrpt::slam::CSensoryFrame		* sf,
+	const mrpt::obs::CActionCollection	* actions,
+	const mrpt::obs::CSensoryFrame		* sf,
 	const bayes::CParticleFilter::TParticleFilterOptions &PF_options )
 {
 	MRPT_START
