@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -19,7 +19,7 @@
 #include <mrpt/poses/CPosePDF.h>
 #include <mrpt/poses/CPosePDFGaussian.h>
 #include <mrpt/poses/CPose3DQuatPDFGaussian.h>
-#include <mrpt/slam/CActionRobotMovement3D.h>
+#include <mrpt/obs/CActionRobotMovement3D.h>
 #include <mrpt/math/utils.h>
 #include <mrpt/math/ops_containers.h>
 #include <mrpt/math/wrap2pi.h>
@@ -31,9 +31,13 @@
 #include <mrpt/opengl/CEllipsoid.h>
 
 using namespace mrpt::slam;
+using namespace mrpt::obs;
+using namespace mrpt::maps;
+using namespace mrpt::math;
 using namespace mrpt::poses;
 using namespace mrpt::utils;
 using namespace mrpt::system;
+using namespace mrpt;
 using namespace std;
 
 
@@ -115,7 +119,7 @@ void CRangeBearingKFSLAM::getCurrentRobotPose(
   ---------------------------------------------------------------*/
 mrpt::poses::CPose3DQuat CRangeBearingKFSLAM::getCurrentRobotPoseMean() const
 {
-	CPose3DQuat  q(UNINITIALIZED_QUATERNION);
+	CPose3DQuat  q(mrpt::math::UNINITIALIZED_QUATERNION);
 	ASSERTDEB_(m_xkk.size()>=7)
 	// Copy xyz+quat: (explicitly unroll the loop)
 	q.m_coords[0] = m_xkk[0];
@@ -1052,7 +1056,7 @@ void CRangeBearingKFSLAM::getLastPartitionLandmarksAsIfFixedSubmaps( size_t K, s
     getLastPartitionLandmarks(landmarksMembership);
 
     // Replace copy:
-    m_lastPartitionSet = tmpParts;
+    m_lastPartitionSet = tmpParts; //-V519
 }
 
 /*---------------------------------------------------------------
