@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -13,7 +13,7 @@
 #include <mrpt/slam/data_association.h>
 #include <mrpt/poses/CPosePDF.h>
 #include <mrpt/poses/CPosePDFGaussian.h>
-#include <mrpt/slam/CActionRobotMovement3D.h>
+#include <mrpt/obs/CActionRobotMovement3D.h>
 #include <mrpt/math/utils.h>
 #include <mrpt/math/wrap2pi.h>
 #include <mrpt/utils/CTicTac.h>
@@ -23,11 +23,14 @@
 #include <mrpt/opengl/CSetOfObjects.h>
 #include <mrpt/opengl/CEllipsoid.h>
 
-
 using namespace mrpt::slam;
+using namespace mrpt::maps;
+using namespace mrpt::math;
+using namespace mrpt::obs;
 using namespace mrpt::poses;
 using namespace mrpt::utils;
 using namespace mrpt::system;
+using namespace mrpt;
 using namespace std;
 
 #define STATS_EXPERIMENT 0
