@@ -2,15 +2,15 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
 
 #include "topography-precomp.h"  // Precompiled headers
 
-#include <mrpt/scanmatching.h>
-#include <mrpt/slam/CObservationGPS.h>
+#include <mrpt/tfest/se3.h>
+#include <mrpt/obs/CObservationGPS.h>
 #include <mrpt/math/data_utils.h>
 #include <mrpt/topography/data_types.h>
 #include <mrpt/topography/conversions.h>
@@ -28,7 +28,7 @@
 
 using namespace std;
 using namespace mrpt;
-using namespace mrpt::slam;
+using namespace mrpt::obs;
 using namespace mrpt::math;
 using namespace mrpt::utils;
 using namespace mrpt::poses;
@@ -49,7 +49,7 @@ std::set<T> make_set( const T& v0, const T& v1 )
  ---------------------------------------------------------------*/
 void  mrpt::topography::path_from_rtk_gps(
 	mrpt::poses::CPose3DInterpolator	&robot_path,
-	const mrpt::slam::CRawlog			&rawlog,
+	const mrpt::obs::CRawlog			&rawlog,
 	size_t 								first,
 	size_t 								last,
 	bool								isGUI,
@@ -391,7 +391,7 @@ void  mrpt::topography::path_from_rtk_gps(
 				unsigned int k;
 				std::map<std::string, CObservationGPSPtr>::iterator g_it;
 
-				for (k=0,g_it=GPS.begin();g_it!=GPS.end();g_it++,k++)
+				for (k=0,g_it=GPS.begin();g_it!=GPS.end();++g_it,++k)
 				{
 					TPoint3D P;
 					mrpt::topography::geodeticToENU_WGS84(
@@ -443,26 +443,25 @@ void  mrpt::topography::path_from_rtk_gps(
 				} // end consistency
 
 				// Use a 6D matching method to estimate the location of the vehicle:
-				CPose3D optimal_pose;
+				CPose3DQuat optimal_pose;
 				double  optimal_scale;
 
 				// "this" (reference map) -> GPS global coordinates
 				// "other" -> GPS local coordinates on the vehicle
-				mrpt::scanmatching::leastSquareErrorRigidTransformation6D( corrs,optimal_pose,optimal_scale, true ); // Force scale=1
+				mrpt::tfest::se3_l2( corrs,optimal_pose,optimal_scale, true ); // Force scale=1
 				//cout << "optimal pose: " << optimal_pose << " " << optimal_scale << endl;
+				MRPT_CHECK_NORMAL_NUMBER( optimal_pose.x() );
+				MRPT_CHECK_NORMAL_NUMBER( optimal_pose.y() );
+				MRPT_CHECK_NORMAL_NUMBER( optimal_pose.z() );
+				MRPT_CHECK_NORMAL_NUMBER( optimal_pose.quat().x() );
+				MRPT_CHECK_NORMAL_NUMBER( optimal_pose.quat().y() );
+				MRPT_CHECK_NORMAL_NUMBER( optimal_pose.quat().z() );
+				MRPT_CHECK_NORMAL_NUMBER( optimal_pose.quat().r() );
 
 				// Final vehicle pose:
-				CPose3D	&veh_pose= optimal_pose;
-
+				const CPose3D veh_pose= optimal_pose;
 
 				// Add to the interpolator:
-				MRPT_CHECK_NORMAL_NUMBER( veh_pose.x() );
-				MRPT_CHECK_NORMAL_NUMBER( veh_pose.y() );
-				MRPT_CHECK_NORMAL_NUMBER( veh_pose.z() );
-				MRPT_CHECK_NORMAL_NUMBER( veh_pose.yaw() );
-				MRPT_CHECK_NORMAL_NUMBER( veh_pose.pitch() );
-				MRPT_CHECK_NORMAL_NUMBER( veh_pose.roll() );
-
 				robot_path.insert( i->first, veh_pose );
 
 				// If we have W_star, compute the pose uncertainty:
@@ -578,14 +577,15 @@ void  mrpt::topography::path_from_rtk_gps(
 		for (map<TTimeStamp,TPoint3D>::iterator i=outInfoTemp.best_gps_path.begin();i!=outInfoTemp.best_gps_path.end();++i)
 		{
 			TPoint3D P;
+			TPoint3D &pl = i->second;
 			mrpt::topography::geodeticToENU_WGS84(
-				TGeodeticCoords(i->second.x,i->second.y,i->second.z),  // i->second.x,i->second.y,i->second.z, // lat, lon, heigh
+				TGeodeticCoords(pl.x,pl.y,pl.z),  // i->second.x,i->second.y,i->second.z, // lat, lon, heigh
 				P, // X Y Z
 				ref );
 
-			i->second.x = P.x + off_X;
-			i->second.y = P.y + off_Y;
-			i->second.z = P.z + off_Z;
+			pl.x = P.x + off_X;
+			pl.y = P.y + off_Y;
+			pl.z = P.z + off_Z;
 		}
 	} // end best_gps_path
 
