@@ -16,7 +16,6 @@
 #include <mrpt/vision/link_pragmas.h>
 #include <unsupported/Eigen/MatrixFunctions>
 
-//class CDeflodo Acronim for "Depth Flow odometry" -> otra opcin de nombre...
 namespace mrpt
 {
 	namespace vision
@@ -36,7 +35,14 @@ namespace mrpt
 		  *    - [DifOdometry-Camera](http://www.mrpt.org/list-of-mrpt-apps/application-difodometry-camera/)
 		  *    - [DifOdometry-Datasets](http://www.mrpt.org/list-of-mrpt-apps/application-difodometry-datasets/)
 		  *
-		  *	Please refer to the respective publication when using this method: *************************
+		  *	Please refer to the respective publication when using this method: 
+		  *		title = {Fast Visual Odometry for {3-D} Range Sensors},
+		  *		author = {Jaimez, Mariano and Gonzalez-Jimenez, Javier},
+		  *		journal = {IEEE Transactions on Robotics},
+		  *		volume = {31},
+		  *		number = {4},
+		  *		pages = {809 - 822},
+		  *		year = {2015}
 		  *
 		  * - JUN/2013: First design.
 		  * - JAN/2014: Integrated into MRPT library.
@@ -66,8 +72,6 @@ namespace mrpt
 			std::vector<Eigen::MatrixXf> yy_old;
 			std::vector<Eigen::MatrixXf> yy_warped;
 
-
-
 			/** Matrices that store the depth derivatives */
 			Eigen::MatrixXf du;
 			Eigen::MatrixXf dv;
@@ -86,9 +90,6 @@ namespace mrpt
 			float g_mask[5][5];
 
 			/** Camera properties: */
-			float f_dist;		//!<Focal lenght (meters)
-			float x_incr;		//!<Separation between pixels (cols) in the sensor array (meters)
-			float y_incr;		//!<Separation between pixels (rows) in the sensor array (meters)
 			float fovh;			//!<Horizontal field of view (rad)
 			float fovv;			//!<Vertical field of view (rad)
 
@@ -164,9 +165,6 @@ namespace mrpt
 
 		public:
 
-			/** Lateral displacement of the lens with respect to the center of the camera (meters) */
-			float lens_disp;
-
 			/** Frames per second (Hz) */
 			float fps;
 
@@ -192,12 +190,6 @@ namespace mrpt
 			    and updates the camera pose */
 			void odometryCalculation();
 
-			/** Set the camera focal lenght */
-			inline void setCameraFocalLenght(float new_f) {f_dist = new_f;}
-
-			/** Get the camera focal lenght */
-			inline float getCameraFocalLenght() const {return f_dist;}
-
 			/** Get the rows and cols of the depth image that are considered by the visual odometry method. */
 			inline void getRowsAndCols(unsigned int &num_rows, unsigned int &num_cols) const {num_rows = rows; num_cols = cols;}
 
