@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -16,10 +16,6 @@ namespace mrpt
 {
 	namespace vision
 	{
-		using mrpt::math::TPose3D;
-		using mrpt::math::TPoint3D;
-		using mrpt::utils::TCamera;
-
 		/** \addtogroup  mrptvision_features
 		    @{ */
 
