@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -24,8 +24,6 @@ namespace mrpt
 	{
 		/** \addtogroup mrpt_vision_grp
 		  *  @{ */
-		using mrpt::poses::CPose3D;
-
 		typedef uint64_t TFeatureID;	//!< Definition of a feature ID
 
 		typedef	uint64_t TLandmarkID;   //!< Unique IDs for landmarks
@@ -48,7 +46,7 @@ namespace mrpt
 			featBCD,				//!< Binary corder detector
 			featSIFT,				//!< Scale Invariant Feature Transform [LOWE'04]
 			featSURF,				//!< Speeded Up Robust Feature [BAY'06]
-			featBeacon,				//!< A especial case: this is not an image feature, but a 2D/3D beacon (used for range-only SLAM from mrpt::slam::CLandmark)
+			featBeacon,				//!< A especial case: this is not an image feature, but a 2D/3D beacon (used for range-only SLAM from mrpt::maps::CLandmark)
 			featFAST,				//!< FAST feature detector, OpenCV's implementation ("Faster and better: A machine learning approach to corner detection", E. Rosten, R. Porter and T. Drummond, PAMI, 2009).
 			featFASTER9,			//!< FASTER-9 detector, Edward Rosten's libcvd implementation optimized for SSE2.
 			featFASTER10,			//!< FASTER-9 detector, Edward Rosten's libcvd implementation optimized for SSE2.
@@ -87,7 +85,7 @@ namespace mrpt
 		struct VISION_IMPEXP TFeatureObservation
 		{
 			inline TFeatureObservation() { }
-			inline TFeatureObservation(const TLandmarkID _id_feature, const TCameraPoseID  _id_frame, const mrpt::utils::TPixelCoordf _px) : id_feature(_id_feature), id_frame(_id_frame), px(_px) { }
+			inline TFeatureObservation(const TLandmarkID _id_feature, const TCameraPoseID  _id_frame, const mrpt::utils::TPixelCoordf &_px) : id_feature(_id_feature), id_frame(_id_frame), px(_px) { }
 
 			TLandmarkID    id_feature;  //!< A unique ID of this feature
 			TCameraPoseID  id_frame;    //!< A unique ID of a "frame" (camera position) from where the feature was observed.
@@ -99,7 +97,7 @@ namespace mrpt
 		struct TRelativeFeaturePos
 		{
 			inline TRelativeFeaturePos() { }
-			inline TRelativeFeaturePos(const mrpt::vision::TCameraPoseID  _id_frame_base, const mrpt::math::TPoint3D _pos) : id_frame_base(_id_frame_base), pos(_pos) {  }
+			inline TRelativeFeaturePos(const mrpt::vision::TCameraPoseID  _id_frame_base, const mrpt::math::TPoint3D &_pos) : id_frame_base(_id_frame_base), pos(_pos) {  }
 
 			mrpt::vision::TCameraPoseID  id_frame_base;	//!< The ID of the camera frame which is the coordinate reference of \a pos
 			mrpt::math::TPoint3D         pos;  //!< The (x,y,z) location of the feature, wrt to the camera frame \a id_frame_base
