@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -27,6 +27,7 @@ using namespace mrpt::vision;
 using namespace mrpt::math;
 using namespace mrpt::system;
 using namespace mrpt::utils;
+using namespace std;
 
 IMPLEMENTS_SERIALIZABLE(CFeature, CSerializable, mrpt::vision)
 
@@ -320,7 +321,7 @@ void CFeature::dumpToConsole() const
     dumpToTextStream( myOut );
 }
 
-void  CFeature::writeToStream(CStream &out,int *version) const
+void  CFeature::writeToStream(mrpt::utils::CStream &out,int *version) const
 {
 	if (version)
 		*version = 2;
@@ -359,12 +360,13 @@ void  CFeature::writeToStream(CStream &out,int *version) const
 	}
 }
 
-void  CFeature::readFromStream(CStream &in,int version)
+void  CFeature::readFromStream(mrpt::utils::CStream &in,int version)
 {
 	switch(version)
 	{
 	case 0:
 	case 1:
+	case 2:
 		{
 			// The coordinates:
 			uint32_t aux_type, aux_KLTS;
@@ -1216,7 +1218,7 @@ bool CFeature::getFirstDescriptorAsMatrix(mrpt::math::CMatrixFloat &desc) const
 			desc(0,i)=descriptors.SURF[i];
 		return true;
 	}
-	else if (descriptors.hasDescriptorSURF())
+	else if (descriptors.hasDescriptorSpinImg())
 	{
 		const size_t nR = descriptors.SpinImg_range_rows;
 		const size_t nC = descriptors.SpinImg.size() / descriptors.SpinImg_range_rows;
