@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -32,6 +32,8 @@
 using namespace mrpt;
 using namespace mrpt::vision;
 using namespace mrpt::system;
+using namespace mrpt::utils;
+using namespace mrpt::math;
 using namespace std;
 
 #if MRPT_HAS_OPENCV
@@ -71,7 +73,7 @@ void  CFeatureExtraction::extractFeaturesSIFT(
 		const TImageROI			&ROI) const
 {
 	bool usingROI = false;
-	if( ROI.xMin != 0 || ROI.xMin != 0 || ROI.xMin != 0 || ROI.xMin != 0 )
+	if( ROI.xMin != 0 || ROI.xMax != 0 || ROI.yMin != 0 || ROI.yMax != 0 )
 		usingROI = true;	// A ROI has been defined
 
 	// ROI can not be managed properly (yet) with these method, so we extract a subimage
