@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -355,11 +355,11 @@ void CStereoRectifyMap::rectify(
 	MRPT_END
 }
 
-/** Overloaded version for in-place rectification of image pairs stored in a mrpt::slam::CObservationStereoImages.
+/** Overloaded version for in-place rectification of image pairs stored in a mrpt::obs::CObservationStereoImages.
   *  Upon return, the new camera intrinsic parameters will be already stored in the observation object.
   */
 void CStereoRectifyMap::rectify(
-	mrpt::slam::CObservationStereoImages & stereo_image_observation,
+	mrpt::obs::CObservationStereoImages & stereo_image_observation,
 	const bool use_internal_mem_cache) const
 {
 	MRPT_START
