@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -50,6 +50,7 @@ If you use this code, please cite the following articles:
 
 #include "checkerboard_ocamcalib_detector.h"
 #include <mrpt/math/CArray.h>
+#include <map>
 
 #if MRPT_HAS_OPENCV
 
@@ -951,9 +952,9 @@ void icvFindConnectedQuads(
 			q = seqStack.top();
 			seqStack.pop(); // cvSeqPop( stack, &q );
 
-			for( i = 0; i < 4; i++ )
+			for( size_t k = 0; k < 4; k++ )
 			{
-				CvCBQuadPtr &neighbor = q->neighbors[i];
+				CvCBQuadPtr &neighbor = q->neighbors[k];
 
 				// If he neighbor exists and the neighbor has more than 0
 				// neighbors and the neighbor has not been classified yet.
@@ -1967,9 +1968,6 @@ int icvGenerateQuads( vector<CvCBQuadPtr> &out_quads, vector<CvCBCornerPtr> &out
 	cv::MemStorage temp_storage = cv::MemStorage(cvCreateMemStorage(0));
 #endif
 
-	out_quads.clear();
-	out_corners.clear();
-
     CvSeq *src_contour = 0;
     CvSeq *root;  // cv::Seq<> root;  //
     CvContourEx* board = 0;
@@ -2071,11 +2069,11 @@ int icvGenerateQuads( vector<CvCBQuadPtr> &out_quads, vector<CvCBCornerPtr> &out
 
 
     // Allocate quad & corner buffers
-	out_quads.clear();	//*out_quads = (CvCBQuad*)cvAlloc(root->total * sizeof((*out_quads)[0]));
+	out_quads.clear();
 	for (int q=0;q<root->total;q++)
 		out_quads.push_back( CvCBQuadPtr(new CvCBQuad) );
 
-	out_corners.clear();	// *out_corners = (CvCBCorner*)cvAlloc(root->total * 4 * sizeof((*out_corners)[0]));
+	out_corners.clear();
 	for (int q=0;q< 4 * root->total;q++)
 		out_corners.push_back( CvCBCornerPtr(new CvCBCorner) );
 
@@ -2084,7 +2082,7 @@ int icvGenerateQuads( vector<CvCBQuadPtr> &out_quads, vector<CvCBCornerPtr> &out
     {
         CvCBQuadPtr &q = out_quads[quad_count];
         src_contour = *(CvSeq**)cvGetSeqElem( root, idx );
-        if( (flags & CV_CALIB_CB_FILTER_QUADS) && src_contour->v_prev != (CvSeq*)board )
+        if( (flags & cv::CALIB_CB_FILTER_QUADS) && src_contour->v_prev != (CvSeq*)board )
             continue;
 
         // Reset group ID
