@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -15,10 +15,10 @@
 #include <mrpt/vision/CFeature.h>
 
 #include <mrpt/poses/CPoint3D.h>
-#include <mrpt/slam/CLandmarksMap.h>
-#include <mrpt/slam/CObservationVisualLandmarks.h>
-#include <mrpt/slam/CObservationStereoImages.h>
-#include <mrpt/slam/CObservationBearingRange.h>
+//#include <mrpt/maps/CLandmarksMap.h>
+#include <mrpt/obs/CObservationVisualLandmarks.h>
+#include <mrpt/obs/CObservationStereoImages.h>
+#include <mrpt/obs/CObservationBearingRange.h>
 #include <mrpt/system/filesystem.h>
 #include <mrpt/system/os.h>
 #include <mrpt/utils/CTicTac.h>
@@ -34,7 +34,7 @@
 using namespace mrpt;
 using namespace mrpt::vision;
 using namespace mrpt::utils;
-using namespace mrpt::slam;
+//using namespace mrpt::maps;
 using namespace mrpt::math;
 using namespace mrpt::system;
 using namespace std;
@@ -604,8 +604,8 @@ void vision::interpolateHistEntry(
     CTimeLogger logger;
     logger.disable();
 
-    double ncbin = cbin + d/2 - 0.5;
-    double nrbin = rbin + d/2 - 0.5;
+    double ncbin = cbin + d/2. - 0.5;
+    double nrbin = rbin + d/2. - 0.5;
 
     int ncbin_i = floor( ncbin );
     int nrbin_i = floor( nrbin );
@@ -913,7 +913,6 @@ TMultiResMatchingOutput vision::matchMultiResolutionFeatures(
     int imageH = rightImage.getHeight();                    // Image height
     int leftFeatCounter = 0;
     int rightFeatCounter = 0;                               // Counter for features
-    vector<double> orientations;
     int patchSize = computeOpts.basePSize;
     int minScale;
     double maxResponse;
@@ -1212,7 +1211,6 @@ int  vision::matchMultiResolutionFeatures(
     CFeatureList auxList1, auxList2;
     mList2.getBothFeatureLists( auxList1, auxList2 );
 
-    vector<int> leftIdx1, leftIdx2, rightIdx1, rightIdx2;
     vector<int> scales1, scales2;
 
     TMultiResMatchingOutput output1, output2;
