@@ -2,22 +2,22 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
 
 #include "vision-precomp.h"   // Precompiled headers
 
-#include <mrpt/slam/CObservationVisualLandmarks.h>
+#include <mrpt/obs/CObservationVisualLandmarks.h>
 #include <mrpt/utils/CStream.h>
 
-using namespace mrpt::slam; 
+using namespace mrpt::obs;
 using namespace mrpt::utils; 
 using namespace mrpt::poses;
 
 // This must be added to any CSerializable class implementation file.
-IMPLEMENTS_SERIALIZABLE(CObservationVisualLandmarks, CObservation,mrpt::slam)
+IMPLEMENTS_SERIALIZABLE(CObservationVisualLandmarks, CObservation,mrpt::obs)
 
 /** Constructor
  */
@@ -30,7 +30,7 @@ CObservationVisualLandmarks::CObservationVisualLandmarks( ) :
 /*---------------------------------------------------------------
   Implements the writing to a CStream capability of CSerializable objects
  ---------------------------------------------------------------*/
-void  CObservationVisualLandmarks::writeToStream(CStream &out, int *version) const
+void  CObservationVisualLandmarks::writeToStream(mrpt::utils::CStream &out, int *version) const
 {
 	if (version)
 		*version = 1;
@@ -47,7 +47,7 @@ void  CObservationVisualLandmarks::writeToStream(CStream &out, int *version) con
 /*---------------------------------------------------------------
   Implements the reading from a CStream capability of CSerializable objects
  ---------------------------------------------------------------*/
-void  CObservationVisualLandmarks::readFromStream(CStream &in, int version)
+void  CObservationVisualLandmarks::readFromStream(mrpt::utils::CStream &in, int version)
 {
 	switch(version)
 	{
@@ -91,3 +91,9 @@ float  CObservationVisualLandmarks::likelihoodWith(
 	return 0;
 }
 
+void CObservationVisualLandmarks::getDescriptionAsText(std::ostream &o) const
+{
+	CObservation::getDescriptionAsText(o);
+
+}
+
