@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -14,7 +14,7 @@
 
 using namespace mrpt;
 using namespace mrpt::utils;
-using namespace mrpt::slam;
+using namespace mrpt::obs;
 using namespace mrpt::system;
 using namespace mrpt::hwdrivers;
 using namespace std;
@@ -59,7 +59,7 @@ void Test_GPS()
 	if (!f) return;
 
 //	bool					thereisData;
-//	mrpt::slam::CObservationGPS	gpsData;
+//	mrpt::obs::CObservationGPS	gpsData;
 
 	CGenericSensor::TListObservations			lstObs;
 	CGenericSensor::TListObservations::iterator 	itObs;
