@@ -2,13 +2,13 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
 
-#include <mrpt/slam/CMultiMetricMap.h>
-#include <mrpt/slam/CObservationBeaconRanges.h>
+#include <mrpt/maps/CMultiMetricMap.h>
+#include <mrpt/obs/CObservationBeaconRanges.h>
 #include <mrpt/slam/CRejectionSamplingRangeOnlyLocalization.h>
 #include <mrpt/random.h>
 #include <mrpt/utils/CConfigFile.h>
@@ -17,8 +17,10 @@
 using namespace mrpt;
 using namespace mrpt::utils;
 using namespace mrpt::slam;
+using namespace mrpt::maps;
 using namespace mrpt::system;
 using namespace mrpt::random;
+using namespace mrpt::poses;
 using namespace std;
 
 float	SIGMA = 0.03f;
@@ -32,13 +34,13 @@ void TestRS()
 
 	// Load the map:
 	CMultiMetricMap									map;
-	mrpt::slam::TSetOfMetricMapInitializers				mapInit;
+	mrpt::maps::TSetOfMetricMapInitializers				mapInit;
 	mapInit.loadFromConfigFile( CConfigFile("_demo_map.ini"),"MetricMap");
 	map.setListOfMaps( &mapInit );
 
 	// Create a dummy observation:
-	mrpt::slam::CObservationBeaconRanges					obs;
-	mrpt::slam::CObservationBeaconRanges::TMeasurement	meas;
+	mrpt::obs::CObservationBeaconRanges					obs;
+	mrpt::obs::CObservationBeaconRanges::TMeasurement	meas;
 	obs.stdError = SIGMA;
 
 	meas.beaconID = 0;
