@@ -2,15 +2,15 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
  
 #include <mrpt/detectors.h>
 #include <mrpt/hwdrivers/CCameraSensor.h>
-#include <mrpt/slam/CColouredPointsMap.h>
-#include <mrpt/slam/CRawlog.h>
+#include <mrpt/maps/CColouredPointsMap.h>
+#include <mrpt/obs/CRawlog.h>
 #include <mrpt/gui.h>
 #include <mrpt/opengl/CPointCloudColoured.h>
 #include <mrpt/opengl/CGridPlaneXY.h>
@@ -18,6 +18,8 @@
 #include <mrpt/math/ops_containers.h>
 
 using namespace mrpt;
+using namespace mrpt::maps;
+using namespace mrpt::obs;
 using namespace mrpt::gui;
 using namespace mrpt::math;
 using namespace mrpt::utils;
@@ -227,7 +229,7 @@ void TestCameraFaceDetection()
 		return;
 	}
 
-	mrpt::slam::CObservationPtr  obs = cam->getNextFrame();
+	mrpt::obs::CObservationPtr  obs = cam->getNextFrame();
 	ASSERT_(obs);
 
 	if ( IS_CLASS(obs, CObservation3DRangeScan) )
@@ -248,7 +250,7 @@ void TestCameraFaceDetection()
 		if( !counter )
 			tictac.Tic();
 
-		mrpt::slam::CObservationPtr  obs;
+		mrpt::obs::CObservationPtr  obs;
 		try 
 		{
 			obs = cam->getNextFrame();
